LICENSES = {
    "0BSD": {
        "name": "0BSD",
        "path": "http://landley.net/toybox/license.html",
        "title": "BSD Zero Clause License",
    },
    "3D-Slicer-1.0": {
        "name": "3D-Slicer-1.0",
        "path": "https://slicer.org/LICENSE",
        "title": "3D Slicer License v1.0",
    },
    "AAL": {
        "name": "AAL",
        "path": "https://opensource.org/licenses/attribution",
        "title": "Attribution Assurance License",
    },
    "ADSL": {
        "name": "ADSL",
        "path": "https://fedoraproject.org/wiki/Licensing/AmazonDigitalServicesLicense",
        "title": "Amazon Digital Services License",
    },
    "AFL-1.1": {
        "name": "AFL-1.1",
        "path": "http://opensource.linux-mirror.org/licenses/afl-1.1.txt",
        "title": "Academic Free License v1.1",
    },
    "AFL-1.2": {
        "name": "AFL-1.2",
        "path": "http://opensource.linux-mirror.org/licenses/afl-1.2.txt",
        "title": "Academic Free License v1.2",
    },
    "AFL-2.0": {
        "name": "AFL-2.0",
        "path": "http://wayback.archive.org/web/20060924134533/http://www.opensource.org/licenses/afl-2.0.txt",
        "title": "Academic Free License v2.0",
    },
    "AFL-2.1": {
        "name": "AFL-2.1",
        "path": "http://opensource.linux-mirror.org/licenses/afl-2.1.txt",
        "title": "Academic Free License v2.1",
    },
    "AFL-3.0": {
        "name": "AFL-3.0",
        "path": "http://www.rosenlaw.com/AFL3.0.htm",
        "title": "Academic Free License v3.0",
    },
    "AGPL-1.0-only": {
        "name": "AGPL-1.0-only",
        "path": "http://www.affero.org/oagpl.html",
        "title": "Affero General Public License v1.0 only",
    },
    "AGPL-1.0-or-later": {
        "name": "AGPL-1.0-or-later",
        "path": "http://www.affero.org/oagpl.html",
        "title": "Affero General Public License v1.0 or later",
    },
    "AGPL-3.0-only": {
        "name": "AGPL-3.0-only",
        "path": "https://www.gnu.org/licenses/agpl.txt",
        "title": "GNU Affero General Public License v3.0 only",
    },
    "AGPL-3.0-or-later": {
        "name": "AGPL-3.0-or-later",
        "path": "https://www.gnu.org/licenses/agpl.txt",
        "title": "GNU Affero General Public License v3.0 or later",
    },
    "AMD-newlib": {
        "name": "AMD-newlib",
        "path": "https://sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/sys/a29khif/_close.S;h=04f52ae00de1dafbd9055ad8d73c5c697a3aae7f;hb=HEAD",
        "title": "AMD newlib License",
    },
    "AMDPLPA": {
        "name": "AMDPLPA",
        "path": "https://fedoraproject.org/wiki/Licensing/AMD_plpa_map_License",
        "title": "AMD's plpa_map.c License",
    },
    "AML": {
        "name": "AML",
        "path": "https://fedoraproject.org/wiki/Licensing/Apple_MIT_License",
        "title": "Apple MIT License",
    },
    "AML-glslang": {
        "name": "AML-glslang",
        "path": "https://github.com/KhronosGroup/glslang/blob/main/LICENSE.txt#L949",
        "title": "AML glslang variant License",
    },
    "AMPAS": {
        "name": "AMPAS",
        "path": "https://fedoraproject.org/wiki/Licensing/BSD#AMPASBSD",
        "title": "Academy of Motion Picture Arts and Sciences BSD",
    },
    "ANTLR-PD": {
        "name": "ANTLR-PD",
        "path": "http://www.antlr2.org/license.html",
        "title": "ANTLR Software Rights Notice",
    },
    "ANTLR-PD-fallback": {
        "name": "ANTLR-PD-fallback",
        "path": "http://www.antlr2.org/license.html",
        "title": "ANTLR Software Rights Notice with license fallback",
    },
    "APAFML": {
        "name": "APAFML",
        "path": "https://fedoraproject.org/wiki/Licensing/AdobePostscriptAFM",
        "title": "Adobe Postscript AFM License",
    },
    "APL-1.0": {
        "name": "APL-1.0",
        "path": "https://opensource.org/licenses/APL-1.0",
        "title": "Adaptive Public License 1.0",
    },
    "APSL-1.0": {
        "name": "APSL-1.0",
        "path": "https://fedoraproject.org/wiki/Licensing/Apple_Public_Source_License_1.0",
        "title": "Apple Public Source License 1.0",
    },
    "APSL-1.1": {
        "name": "APSL-1.1",
        "path": "http://www.opensource.apple.com/source/IOSerialFamily/IOSerialFamily-7/APPLE_LICENSE",
        "title": "Apple Public Source License 1.1",
    },
    "APSL-1.2": {
        "name": "APSL-1.2",
        "path": "http://www.samurajdata.se/opensource/mirror/licenses/apsl.php",
        "title": "Apple Public Source License 1.2",
    },
    "APSL-2.0": {
        "name": "APSL-2.0",
        "path": "http://www.opensource.apple.com/license/apsl/",
        "title": "Apple Public Source License 2.0",
    },
    "ASWF-Digital-Assets-1.0": {
        "name": "ASWF-Digital-Assets-1.0",
        "path": "https://github.com/AcademySoftwareFoundation/foundation/blob/main/digital_assets/aswf_digital_assets_license_v1.0.txt",
        "title": "ASWF Digital Assets License version 1.0",
    },
    "ASWF-Digital-Assets-1.1": {
        "name": "ASWF-Digital-Assets-1.1",
        "path": "https://github.com/AcademySoftwareFoundation/foundation/blob/main/digital_assets/aswf_digital_assets_license_v1.1.txt",
        "title": "ASWF Digital Assets License 1.1",
    },
    "Abstyles": {
        "name": "Abstyles",
        "path": "https://fedoraproject.org/wiki/Licensing/Abstyles",
        "title": "Abstyles License",
    },
    "AdaCore-doc": {
        "name": "AdaCore-doc",
        "path": "https://github.com/AdaCore/xmlada/blob/master/docs/index.rst",
        "title": "AdaCore Doc License",
    },
    "Adobe-2006": {
        "name": "Adobe-2006",
        "path": "https://fedoraproject.org/wiki/Licensing/AdobeLicense",
        "title": "Adobe Systems Incorporated Source Code License Agreement",
    },
    "Adobe-Display-PostScript": {
        "name": "Adobe-Display-PostScript",
        "path": "https://gitlab.freedesktop.org/xorg/xserver/-/blob/master/COPYING?ref_type=heads#L752",
        "title": "Adobe Display PostScript License",
    },
    "Adobe-Glyph": {
        "name": "Adobe-Glyph",
        "path": "https://fedoraproject.org/wiki/Licensing/MIT#AdobeGlyph",
        "title": "Adobe Glyph List License",
    },
    "Adobe-Utopia": {
        "name": "Adobe-Utopia",
        "path": "https://gitlab.freedesktop.org/xorg/font/adobe-utopia-100dpi/-/blob/master/COPYING?ref_type=heads",
        "title": "Adobe Utopia Font License",
    },
    "Afmparse": {
        "name": "Afmparse",
        "path": "https://fedoraproject.org/wiki/Licensing/Afmparse",
        "title": "Afmparse License",
    },
    "Aladdin": {
        "name": "Aladdin",
        "path": "http://pages.cs.wisc.edu/~ghost/doc/AFPL/6.01/Public.htm",
        "title": "Aladdin Free Public License",
    },
    "Apache-1.0": {
        "name": "Apache-1.0",
        "path": "http://www.apache.org/licenses/LICENSE-1.0",
        "title": "Apache License 1.0",
    },
    "Apache-1.1": {
        "name": "Apache-1.1",
        "path": "http://apache.org/licenses/LICENSE-1.1",
        "title": "Apache License 1.1",
    },
    "Apache-2.0": {
        "name": "Apache-2.0",
        "path": "https://www.apache.org/licenses/LICENSE-2.0",
        "title": "Apache License 2.0",
    },
    "App-s2p": {
        "name": "App-s2p",
        "path": "https://fedoraproject.org/wiki/Licensing/App-s2p",
        "title": "App::s2p License",
    },
    "Arphic-1999": {
        "name": "Arphic-1999",
        "path": "http://ftp.gnu.org/gnu/non-gnu/chinese-fonts-truetype/LICENSE",
        "title": "Arphic Public License",
    },
    "Artistic-1.0": {
        "name": "Artistic-1.0",
        "path": "https://opensource.org/licenses/Artistic-1.0",
        "title": "Artistic License 1.0",
    },
    "Artistic-1.0-Perl": {
        "name": "Artistic-1.0-Perl",
        "path": "http://dev.perl.org/licenses/artistic.html",
        "title": "Artistic License 1.0 (Perl)",
    },
    "Artistic-1.0-cl8": {
        "name": "Artistic-1.0-cl8",
        "path": "https://opensource.org/licenses/Artistic-1.0",
        "title": "Artistic License 1.0 w/clause 8",
    },
    "Artistic-2.0": {
        "name": "Artistic-2.0",
        "path": "http://www.perlfoundation.org/artistic_license_2_0",
        "title": "Artistic License 2.0",
    },
    "BSD-1-Clause": {
        "name": "BSD-1-Clause",
        "path": "https://svnweb.freebsd.org/base/head/include/ifaddrs.h?revision=326823",
        "title": "BSD 1-Clause License",
    },
    "BSD-2-Clause": {
        "name": "BSD-2-Clause",
        "path": "https://opensource.org/licenses/BSD-2-Clause",
        "title": 'BSD 2-Clause "Simplified" License',
    },
    "BSD-2-Clause-Darwin": {
        "name": "BSD-2-Clause-Darwin",
        "path": "https://github.com/file/file/blob/master/COPYING",
        "title": "BSD 2-Clause - Ian Darwin variant",
    },
    "BSD-2-Clause-Patent": {
        "name": "BSD-2-Clause-Patent",
        "path": "https://opensource.org/licenses/BSDplusPatent",
        "title": "BSD-2-Clause Plus Patent License",
    },
    "BSD-2-Clause-Views": {
        "name": "BSD-2-Clause-Views",
        "path": "http://www.freebsd.org/copyright/freebsd-license.html",
        "title": "BSD 2-Clause with views sentence",
    },
    "BSD-2-Clause-first-lines": {
        "name": "BSD-2-Clause-first-lines",
        "path": "https://github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L664-L690",
        "title": "BSD 2-Clause - first lines requirement",
    },
    "BSD-3-Clause": {
        "name": "BSD-3-Clause",
        "path": "https://opensource.org/licenses/BSD-3-Clause",
        "title": 'BSD 3-Clause "New" or "Revised" License',
    },
    "BSD-3-Clause-Attribution": {
        "name": "BSD-3-Clause-Attribution",
        "path": "https://fedoraproject.org/wiki/Licensing/BSD_with_Attribution",
        "title": "BSD with attribution",
    },
    "BSD-3-Clause-Clear": {
        "name": "BSD-3-Clause-Clear",
        "path": "http://labs.metacarta.com/license-explanation.html#license",
        "title": "BSD 3-Clause Clear License",
    },
    "BSD-3-Clause-HP": {
        "name": "BSD-3-Clause-HP",
        "path": "https://github.com/zdohnal/hplip/blob/master/COPYING#L939",
        "title": "Hewlett-Packard BSD variant license",
    },
    "BSD-3-Clause-LBNL": {
        "name": "BSD-3-Clause-LBNL",
        "path": "https://fedoraproject.org/wiki/Licensing/LBNLBSD",
        "title": "Lawrence Berkeley National Labs BSD variant license",
    },
    "BSD-3-Clause-Modification": {
        "name": "BSD-3-Clause-Modification",
        "path": "https://fedoraproject.org/wiki/Licensing:BSD#Modification_Variant",
        "title": "BSD 3-Clause Modification",
    },
    "BSD-3-Clause-No-Military-License": {
        "name": "BSD-3-Clause-No-Military-License",
        "path": "https://gitlab.syncad.com/hive/dhive/-/blob/master/LICENSE",
        "title": "BSD 3-Clause No Military License",
    },
    "BSD-3-Clause-No-Nuclear-License": {
        "name": "BSD-3-Clause-No-Nuclear-License",
        "path": "http://download.oracle.com/otn-pub/java/licenses/bsd.txt",
        "title": "BSD 3-Clause No Nuclear License",
    },
    "BSD-3-Clause-No-Nuclear-License-2014": {
        "name": "BSD-3-Clause-No-Nuclear-License-2014",
        "path": "https://java.net/projects/javaeetutorial/pages/BerkeleyLicense",
        "title": "BSD 3-Clause No Nuclear License 2014",
    },
    "BSD-3-Clause-No-Nuclear-Warranty": {
        "name": "BSD-3-Clause-No-Nuclear-Warranty",
        "path": "https://jogamp.org/git/?p=gluegen.git;a=blob_plain;f=LICENSE.txt",
        "title": "BSD 3-Clause No Nuclear Warranty",
    },
    "BSD-3-Clause-Open-MPI": {
        "name": "BSD-3-Clause-Open-MPI",
        "path": "https://www.open-mpi.org/community/license.php",
        "title": "BSD 3-Clause Open MPI variant",
    },
    "BSD-3-Clause-Sun": {
        "name": "BSD-3-Clause-Sun",
        "path": "https://github.com/xmlark/msv/blob/b9316e2f2270bc1606952ea4939ec87fbba157f3/xsdlib/src/main/java/com/sun/msv/datatype/regexp/InternalImpl.java",
        "title": "BSD 3-Clause Sun Microsystems",
    },
    "BSD-3-Clause-acpica": {
        "name": "BSD-3-Clause-acpica",
        "path": "https://github.com/acpica/acpica/blob/master/source/common/acfileio.c#L119",
        "title": "BSD 3-Clause acpica variant",
    },
    "BSD-3-Clause-flex": {
        "name": "BSD-3-Clause-flex",
        "path": "https://github.com/westes/flex/blob/master/COPYING",
        "title": "BSD 3-Clause Flex variant",
    },
    "BSD-4-Clause": {
        "name": "BSD-4-Clause",
        "path": "http://directory.fsf.org/wiki/License:BSD_4Clause",
        "title": 'BSD 4-Clause "Original" or "Old" License',
    },
    "BSD-4-Clause-Shortened": {
        "name": "BSD-4-Clause-Shortened",
        "path": "https://metadata.ftp-master.debian.org/changelogs//main/a/arpwatch/arpwatch_2.1a15-7_copyright",
        "title": "BSD 4 Clause Shortened",
    },
    "BSD-4-Clause-UC": {
        "name": "BSD-4-Clause-UC",
        "path": "http://www.freebsd.org/copyright/license.html",
        "title": "BSD-4-Clause (University of California-Specific)",
    },
    "BSD-4.3RENO": {
        "name": "BSD-4.3RENO",
        "path": "https://sourceware.org/git/?p=binutils-gdb.git;a=blob;f=libiberty/strcasecmp.c;h=131d81c2ce7881fa48c363dc5bf5fb302c61ce0b;hb=HEAD",
        "title": "BSD 4.3 RENO License",
    },
    "BSD-4.3TAHOE": {
        "name": "BSD-4.3TAHOE",
        "path": "https://github.com/389ds/389-ds-base/blob/main/ldap/include/sysexits-compat.h#L15",
        "title": "BSD 4.3 TAHOE License",
    },
    "BSD-Advertising-Acknowledgement": {
        "name": "BSD-Advertising-Acknowledgement",
        "path": "https://github.com/python-excel/xlrd/blob/master/LICENSE#L33",
        "title": "BSD Advertising Acknowledgement License",
    },
    "BSD-Attribution-HPND-disclaimer": {
        "name": "BSD-Attribution-HPND-disclaimer",
        "path": "https://github.com/cyrusimap/cyrus-sasl/blob/master/COPYING",
        "title": "BSD with Attribution and HPND disclaimer",
    },
    "BSD-Inferno-Nettverk": {
        "name": "BSD-Inferno-Nettverk",
        "path": "https://www.inet.no/dante/LICENSE",
        "title": "BSD-Inferno-Nettverk",
    },
    "BSD-Protection": {
        "name": "BSD-Protection",
        "path": "https://fedoraproject.org/wiki/Licensing/BSD_Protection_License",
        "title": "BSD Protection License",
    },
    "BSD-Source-Code": {
        "name": "BSD-Source-Code",
        "path": "https://github.com/robbiehanson/CocoaHTTPServer/blob/master/LICENSE.txt",
        "title": "BSD Source Code Attribution",
    },
    "BSD-Source-beginning-file": {
        "name": "BSD-Source-beginning-file",
        "path": "https://github.com/lattera/freebsd/blob/master/sys/cam/cam.c#L4",
        "title": "BSD Source Code Attribution - beginning of file variant",
    },
    "BSD-Systemics": {
        "name": "BSD-Systemics",
        "path": "https://metacpan.org/release/DPARIS/Crypt-DES-2.07/source/COPYRIGHT",
        "title": "Systemics BSD variant license",
    },
    "BSD-Systemics-W3Works": {
        "name": "BSD-Systemics-W3Works",
        "path": "https://metacpan.org/release/DPARIS/Crypt-Blowfish-2.14/source/COPYRIGHT#L7",
        "title": "Systemics W3Works BSD variant license",
    },
    "BSL-1.0": {
        "name": "BSL-1.0",
        "path": "http://www.boost.org/LICENSE_1_0.txt",
        "title": "Boost Software License 1.0",
    },
    "BUSL-1.1": {
        "name": "BUSL-1.1",
        "path": "https://mariadb.com/bsl11/",
        "title": "Business Source License 1.1",
    },
    "Baekmuk": {
        "name": "Baekmuk",
        "path": "https://fedoraproject.org/wiki/Licensing:Baekmuk?rd=Licensing/Baekmuk",
        "title": "Baekmuk License",
    },
    "Bahyph": {
        "name": "Bahyph",
        "path": "https://fedoraproject.org/wiki/Licensing/Bahyph",
        "title": "Bahyph License",
    },
    "Barr": {
        "name": "Barr",
        "path": "https://fedoraproject.org/wiki/Licensing/Barr",
        "title": "Barr License",
    },
    "Beerware": {
        "name": "Beerware",
        "path": "https://fedoraproject.org/wiki/Licensing/Beerware",
        "title": "Beerware License",
    },
    "BitTorrent-1.0": {
        "name": "BitTorrent-1.0",
        "path": "http://sources.gentoo.org/cgi-bin/viewvc.cgi/gentoo-x86/licenses/BitTorrent?r1=1.1&r2=1.1.1.1&diff_format=s",
        "title": "BitTorrent Open Source License v1.0",
    },
    "BitTorrent-1.1": {
        "name": "BitTorrent-1.1",
        "path": "http://directory.fsf.org/wiki/License:BitTorrentOSL1.1",
        "title": "BitTorrent Open Source License v1.1",
    },
    "Bitstream-Charter": {
        "name": "Bitstream-Charter",
        "path": "https://fedoraproject.org/wiki/Licensing/Charter#License_Text",
        "title": "Bitstream Charter Font License",
    },
    "Bitstream-Vera": {
        "name": "Bitstream-Vera",
        "path": "https://web.archive.org/web/20080207013128/http://www.gnome.org/fonts/",
        "title": "Bitstream Vera Font License",
    },
    "BlueOak-1.0.0": {
        "name": "BlueOak-1.0.0",
        "path": "https://blueoakcouncil.org/license/1.0.0",
        "title": "Blue Oak Model License 1.0.0",
    },
    "Boehm-GC": {
        "name": "Boehm-GC",
        "path": "https://fedoraproject.org/wiki/Licensing:MIT#Another_Minimal_variant_(found_in_libatomic_ops)",
        "title": "Boehm-Demers-Weiser GC License",
    },
    "Borceux": {
        "name": "Borceux",
        "path": "https://fedoraproject.org/wiki/Licensing/Borceux",
        "title": "Borceux license",
    },
    "Brian-Gladman-2-Clause": {
        "name": "Brian-Gladman-2-Clause",
        "path": "https://github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L140-L156",
        "title": "Brian Gladman 2-Clause License",
    },
    "Brian-Gladman-3-Clause": {
        "name": "Brian-Gladman-3-Clause",
        "path": "https://github.com/SWI-Prolog/packages-clib/blob/master/sha1/brg_endian.h",
        "title": "Brian Gladman 3-Clause License",
    },
    "C-UDA-1.0": {
        "name": "C-UDA-1.0",
        "path": "https://github.com/microsoft/Computational-Use-of-Data-Agreement/blob/master/C-UDA-1.0.md",
        "title": "Computational Use of Data Agreement v1.0",
    },
    "CAL-1.0": {
        "name": "CAL-1.0",
        "path": "http://cryptographicautonomylicense.com/license-text.html",
        "title": "Cryptographic Autonomy License 1.0",
    },
    "CAL-1.0-Combined-Work-Exception": {
        "name": "CAL-1.0-Combined-Work-Exception",
        "path": "http://cryptographicautonomylicense.com/license-text.html",
        "title": "Cryptographic Autonomy License 1.0 (Combined Work " "Exception)",
    },
    "CATOSL-1.1": {
        "name": "CATOSL-1.1",
        "path": "https://opensource.org/licenses/CATOSL-1.1",
        "title": "Computer Associates Trusted Open Source License 1.1",
    },
    "CC-BY-1.0": {
        "name": "CC-BY-1.0",
        "path": "https://creativecommons.org/licenses/by/1.0/legalcode",
        "title": "Creative Commons Attribution 1.0 Generic",
    },
    "CC-BY-2.0": {
        "name": "CC-BY-2.0",
        "path": "https://creativecommons.org/licenses/by/2.0/legalcode",
        "title": "Creative Commons Attribution 2.0 Generic",
    },
    "CC-BY-2.5": {
        "name": "CC-BY-2.5",
        "path": "https://creativecommons.org/licenses/by/2.5/legalcode",
        "title": "Creative Commons Attribution 2.5 Generic",
    },
    "CC-BY-2.5-AU": {
        "name": "CC-BY-2.5-AU",
        "path": "https://creativecommons.org/licenses/by/2.5/au/legalcode",
        "title": "Creative Commons Attribution 2.5 Australia",
    },
    "CC-BY-3.0": {
        "name": "CC-BY-3.0",
        "path": "https://creativecommons.org/licenses/by/3.0/legalcode",
        "title": "Creative Commons Attribution 3.0 Unported",
    },
    "CC-BY-3.0-AT": {
        "name": "CC-BY-3.0-AT",
        "path": "https://creativecommons.org/licenses/by/3.0/at/legalcode",
        "title": "Creative Commons Attribution 3.0 Austria",
    },
    "CC-BY-3.0-AU": {
        "name": "CC-BY-3.0-AU",
        "path": "https://creativecommons.org/licenses/by/3.0/au/legalcode",
        "title": "Creative Commons Attribution 3.0 Australia",
    },
    "CC-BY-3.0-DE": {
        "name": "CC-BY-3.0-DE",
        "path": "https://creativecommons.org/licenses/by/3.0/de/legalcode",
        "title": "Creative Commons Attribution 3.0 Germany",
    },
    "CC-BY-3.0-IGO": {
        "name": "CC-BY-3.0-IGO",
        "path": "https://creativecommons.org/licenses/by/3.0/igo/legalcode",
        "title": "Creative Commons Attribution 3.0 IGO",
    },
    "CC-BY-3.0-NL": {
        "name": "CC-BY-3.0-NL",
        "path": "https://creativecommons.org/licenses/by/3.0/nl/legalcode",
        "title": "Creative Commons Attribution 3.0 Netherlands",
    },
    "CC-BY-3.0-US": {
        "name": "CC-BY-3.0-US",
        "path": "https://creativecommons.org/licenses/by/3.0/us/legalcode",
        "title": "Creative Commons Attribution 3.0 United States",
    },
    "CC-BY-4.0": {
        "name": "CC-BY-4.0",
        "path": "https://creativecommons.org/licenses/by/4.0/legalcode",
        "title": "Creative Commons Attribution 4.0 International",
    },
    "CC-BY-NC-1.0": {
        "name": "CC-BY-NC-1.0",
        "path": "https://creativecommons.org/licenses/by-nc/1.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial 1.0 Generic",
    },
    "CC-BY-NC-2.0": {
        "name": "CC-BY-NC-2.0",
        "path": "https://creativecommons.org/licenses/by-nc/2.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial 2.0 Generic",
    },
    "CC-BY-NC-2.5": {
        "name": "CC-BY-NC-2.5",
        "path": "https://creativecommons.org/licenses/by-nc/2.5/legalcode",
        "title": "Creative Commons Attribution Non Commercial 2.5 Generic",
    },
    "CC-BY-NC-3.0": {
        "name": "CC-BY-NC-3.0",
        "path": "https://creativecommons.org/licenses/by-nc/3.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial 3.0 Unported",
    },
    "CC-BY-NC-3.0-DE": {
        "name": "CC-BY-NC-3.0-DE",
        "path": "https://creativecommons.org/licenses/by-nc/3.0/de/legalcode",
        "title": "Creative Commons Attribution Non Commercial 3.0 Germany",
    },
    "CC-BY-NC-4.0": {
        "name": "CC-BY-NC-4.0",
        "path": "https://creativecommons.org/licenses/by-nc/4.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial 4.0 International",
    },
    "CC-BY-NC-ND-1.0": {
        "name": "CC-BY-NC-ND-1.0",
        "path": "https://creativecommons.org/licenses/by-nd-nc/1.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial No Derivatives 1.0 " "Generic",
    },
    "CC-BY-NC-ND-2.0": {
        "name": "CC-BY-NC-ND-2.0",
        "path": "https://creativecommons.org/licenses/by-nc-nd/2.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial No Derivatives 2.0 " "Generic",
    },
    "CC-BY-NC-ND-2.5": {
        "name": "CC-BY-NC-ND-2.5",
        "path": "https://creativecommons.org/licenses/by-nc-nd/2.5/legalcode",
        "title": "Creative Commons Attribution Non Commercial No Derivatives 2.5 " "Generic",
    },
    "CC-BY-NC-ND-3.0": {
        "name": "CC-BY-NC-ND-3.0",
        "path": "https://creativecommons.org/licenses/by-nc-nd/3.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial No Derivatives 3.0 " "Unported",
    },
    "CC-BY-NC-ND-3.0-DE": {
        "name": "CC-BY-NC-ND-3.0-DE",
        "path": "https://creativecommons.org/licenses/by-nc-nd/3.0/de/legalcode",
        "title": "Creative Commons Attribution Non Commercial No Derivatives 3.0 " "Germany",
    },
    "CC-BY-NC-ND-3.0-IGO": {
        "name": "CC-BY-NC-ND-3.0-IGO",
        "path": "https://creativecommons.org/licenses/by-nc-nd/3.0/igo/legalcode",
        "title": "Creative Commons Attribution Non Commercial No Derivatives 3.0 " "IGO",
    },
    "CC-BY-NC-ND-4.0": {
        "name": "CC-BY-NC-ND-4.0",
        "path": "https://creativecommons.org/licenses/by-nc-nd/4.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial No Derivatives 4.0 " "International",
    },
    "CC-BY-NC-SA-1.0": {
        "name": "CC-BY-NC-SA-1.0",
        "path": "https://creativecommons.org/licenses/by-nc-sa/1.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 1.0 " "Generic",
    },
    "CC-BY-NC-SA-2.0": {
        "name": "CC-BY-NC-SA-2.0",
        "path": "https://creativecommons.org/licenses/by-nc-sa/2.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 2.0 " "Generic",
    },
    "CC-BY-NC-SA-2.0-DE": {
        "name": "CC-BY-NC-SA-2.0-DE",
        "path": "https://creativecommons.org/licenses/by-nc-sa/2.0/de/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 2.0 " "Germany",
    },
    "CC-BY-NC-SA-2.0-FR": {
        "name": "CC-BY-NC-SA-2.0-FR",
        "path": "https://creativecommons.org/licenses/by-nc-sa/2.0/fr/legalcode",
        "title": "Creative Commons Attribution-NonCommercial-ShareAlike 2.0 " "France",
    },
    "CC-BY-NC-SA-2.0-UK": {
        "name": "CC-BY-NC-SA-2.0-UK",
        "path": "https://creativecommons.org/licenses/by-nc-sa/2.0/uk/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 2.0 " "England and Wales",
    },
    "CC-BY-NC-SA-2.5": {
        "name": "CC-BY-NC-SA-2.5",
        "path": "https://creativecommons.org/licenses/by-nc-sa/2.5/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 2.5 " "Generic",
    },
    "CC-BY-NC-SA-3.0": {
        "name": "CC-BY-NC-SA-3.0",
        "path": "https://creativecommons.org/licenses/by-nc-sa/3.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 3.0 " "Unported",
    },
    "CC-BY-NC-SA-3.0-DE": {
        "name": "CC-BY-NC-SA-3.0-DE",
        "path": "https://creativecommons.org/licenses/by-nc-sa/3.0/de/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 3.0 " "Germany",
    },
    "CC-BY-NC-SA-3.0-IGO": {
        "name": "CC-BY-NC-SA-3.0-IGO",
        "path": "https://creativecommons.org/licenses/by-nc-sa/3.0/igo/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 3.0 " "IGO",
    },
    "CC-BY-NC-SA-4.0": {
        "name": "CC-BY-NC-SA-4.0",
        "path": "https://creativecommons.org/licenses/by-nc-sa/4.0/legalcode",
        "title": "Creative Commons Attribution Non Commercial Share Alike 4.0 " "International",
    },
    "CC-BY-ND-1.0": {
        "name": "CC-BY-ND-1.0",
        "path": "https://creativecommons.org/licenses/by-nd/1.0/legalcode",
        "title": "Creative Commons Attribution No Derivatives 1.0 Generic",
    },
    "CC-BY-ND-2.0": {
        "name": "CC-BY-ND-2.0",
        "path": "https://creativecommons.org/licenses/by-nd/2.0/legalcode",
        "title": "Creative Commons Attribution No Derivatives 2.0 Generic",
    },
    "CC-BY-ND-2.5": {
        "name": "CC-BY-ND-2.5",
        "path": "https://creativecommons.org/licenses/by-nd/2.5/legalcode",
        "title": "Creative Commons Attribution No Derivatives 2.5 Generic",
    },
    "CC-BY-ND-3.0": {
        "name": "CC-BY-ND-3.0",
        "path": "https://creativecommons.org/licenses/by-nd/3.0/legalcode",
        "title": "Creative Commons Attribution No Derivatives 3.0 Unported",
    },
    "CC-BY-ND-3.0-DE": {
        "name": "CC-BY-ND-3.0-DE",
        "path": "https://creativecommons.org/licenses/by-nd/3.0/de/legalcode",
        "title": "Creative Commons Attribution No Derivatives 3.0 Germany",
    },
    "CC-BY-ND-4.0": {
        "name": "CC-BY-ND-4.0",
        "path": "https://creativecommons.org/licenses/by-nd/4.0/legalcode",
        "title": "Creative Commons Attribution No Derivatives 4.0 International",
    },
    "CC-BY-SA-1.0": {
        "name": "CC-BY-SA-1.0",
        "path": "https://creativecommons.org/licenses/by-sa/1.0/legalcode",
        "title": "Creative Commons Attribution Share Alike 1.0 Generic",
    },
    "CC-BY-SA-2.0": {
        "name": "CC-BY-SA-2.0",
        "path": "https://creativecommons.org/licenses/by-sa/2.0/legalcode",
        "title": "Creative Commons Attribution Share Alike 2.0 Generic",
    },
    "CC-BY-SA-2.0-UK": {
        "name": "CC-BY-SA-2.0-UK",
        "path": "https://creativecommons.org/licenses/by-sa/2.0/uk/legalcode",
        "title": "Creative Commons Attribution Share Alike 2.0 England and Wales",
    },
    "CC-BY-SA-2.1-JP": {
        "name": "CC-BY-SA-2.1-JP",
        "path": "https://creativecommons.org/licenses/by-sa/2.1/jp/legalcode",
        "title": "Creative Commons Attribution Share Alike 2.1 Japan",
    },
    "CC-BY-SA-2.5": {
        "name": "CC-BY-SA-2.5",
        "path": "https://creativecommons.org/licenses/by-sa/2.5/legalcode",
        "title": "Creative Commons Attribution Share Alike 2.5 Generic",
    },
    "CC-BY-SA-3.0": {
        "name": "CC-BY-SA-3.0",
        "path": "https://creativecommons.org/licenses/by-sa/3.0/legalcode",
        "title": "Creative Commons Attribution Share Alike 3.0 Unported",
    },
    "CC-BY-SA-3.0-AT": {
        "name": "CC-BY-SA-3.0-AT",
        "path": "https://creativecommons.org/licenses/by-sa/3.0/at/legalcode",
        "title": "Creative Commons Attribution Share Alike 3.0 Austria",
    },
    "CC-BY-SA-3.0-DE": {
        "name": "CC-BY-SA-3.0-DE",
        "path": "https://creativecommons.org/licenses/by-sa/3.0/de/legalcode",
        "title": "Creative Commons Attribution Share Alike 3.0 Germany",
    },
    "CC-BY-SA-3.0-IGO": {
        "name": "CC-BY-SA-3.0-IGO",
        "path": "https://creativecommons.org/licenses/by-sa/3.0/igo/legalcode",
        "title": "Creative Commons Attribution-ShareAlike 3.0 IGO",
    },
    "CC-BY-SA-4.0": {
        "name": "CC-BY-SA-4.0",
        "path": "https://creativecommons.org/licenses/by-sa/4.0/legalcode",
        "title": "Creative Commons Attribution Share Alike 4.0 International",
    },
    "CC-PDDC": {
        "name": "CC-PDDC",
        "path": "https://creativecommons.org/licenses/publicdomain/",
        "title": "Creative Commons Public Domain Dedication and Certification",
    },
    "CC0-1.0": {
        "name": "CC0-1.0",
        "path": "https://creativecommons.org/publicdomain/zero/1.0/legalcode",
        "title": "Creative Commons Zero v1.0 Universal",
    },
    "CDDL-1.0": {
        "name": "CDDL-1.0",
        "path": "https://opensource.org/licenses/cddl1",
        "title": "Common Development and Distribution License 1.0",
    },
    "CDDL-1.1": {
        "name": "CDDL-1.1",
        "path": "http://glassfish.java.net/public/CDDL+GPL_1_1.html",
        "title": "Common Development and Distribution License 1.1",
    },
    "CDL-1.0": {
        "name": "CDL-1.0",
        "path": "http://www.opensource.apple.com/cdl/",
        "title": "Common Documentation License 1.0",
    },
    "CDLA-Permissive-1.0": {
        "name": "CDLA-Permissive-1.0",
        "path": "https://cdla.io/permissive-1-0",
        "title": "Community Data License Agreement Permissive 1.0",
    },
    "CDLA-Permissive-2.0": {
        "name": "CDLA-Permissive-2.0",
        "path": "https://cdla.dev/permissive-2-0",
        "title": "Community Data License Agreement Permissive 2.0",
    },
    "CDLA-Sharing-1.0": {
        "name": "CDLA-Sharing-1.0",
        "path": "https://cdla.io/sharing-1-0",
        "title": "Community Data License Agreement Sharing 1.0",
    },
    "CECILL-1.0": {
        "name": "CECILL-1.0",
        "path": "http://www.cecill.info/licences/Licence_CeCILL_V1-fr.html",
        "title": "CeCILL Free Software License Agreement v1.0",
    },
    "CECILL-1.1": {
        "name": "CECILL-1.1",
        "path": "http://www.cecill.info/licences/Licence_CeCILL_V1.1-US.html",
        "title": "CeCILL Free Software License Agreement v1.1",
    },
    "CECILL-2.0": {
        "name": "CECILL-2.0",
        "path": "http://www.cecill.info/licences/Licence_CeCILL_V2-en.html",
        "title": "CeCILL Free Software License Agreement v2.0",
    },
    "CECILL-2.1": {
        "name": "CECILL-2.1",
        "path": "http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html",
        "title": "CeCILL Free Software License Agreement v2.1",
    },
    "CECILL-B": {
        "name": "CECILL-B",
        "path": "http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html",
        "title": "CeCILL-B Free Software License Agreement",
    },
    "CECILL-C": {
        "name": "CECILL-C",
        "path": "http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html",
        "title": "CeCILL-C Free Software License Agreement",
    },
    "CERN-OHL-1.1": {
        "name": "CERN-OHL-1.1",
        "path": "https://www.ohwr.org/project/licenses/wikis/cern-ohl-v1.1",
        "title": "CERN Open Hardware Licence v1.1",
    },
    "CERN-OHL-1.2": {
        "name": "CERN-OHL-1.2",
        "path": "https://www.ohwr.org/project/licenses/wikis/cern-ohl-v1.2",
        "title": "CERN Open Hardware Licence v1.2",
    },
    "CERN-OHL-P-2.0": {
        "name": "CERN-OHL-P-2.0",
        "path": "https://www.ohwr.org/project/cernohl/wikis/Documents/CERN-OHL-version-2",
        "title": "CERN Open Hardware Licence Version 2 - Permissive",
    },
    "CERN-OHL-S-2.0": {
        "name": "CERN-OHL-S-2.0",
        "path": "https://www.ohwr.org/project/cernohl/wikis/Documents/CERN-OHL-version-2",
        "title": "CERN Open Hardware Licence Version 2 - Strongly Reciprocal",
    },
    "CERN-OHL-W-2.0": {
        "name": "CERN-OHL-W-2.0",
        "path": "https://www.ohwr.org/project/cernohl/wikis/Documents/CERN-OHL-version-2",
        "title": "CERN Open Hardware Licence Version 2 - Weakly Reciprocal",
    },
    "CFITSIO": {
        "name": "CFITSIO",
        "path": "https://heasarc.gsfc.nasa.gov/docs/software/fitsio/c/f_user/node9.html",
        "title": "CFITSIO License",
    },
    "CMU-Mach": {
        "name": "CMU-Mach",
        "path": "https://www.cs.cmu.edu/~410/licenses.html",
        "title": "CMU Mach License",
    },
    "CMU-Mach-nodoc": {
        "name": "CMU-Mach-nodoc",
        "path": "https://github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L718-L728",
        "title": "CMU    Mach - no notices-in-documentation variant",
    },
    "CNRI-Jython": {
        "name": "CNRI-Jython",
        "path": "http://www.jython.org/license.html",
        "title": "CNRI Jython License",
    },
    "CNRI-Python": {
        "name": "CNRI-Python",
        "path": "https://opensource.org/licenses/CNRI-Python",
        "title": "CNRI Python License",
    },
    "CNRI-Python-GPL-Compatible": {
        "name": "CNRI-Python-GPL-Compatible",
        "path": "http://www.python.org/download/releases/1.6.1/download_win/",
        "title": "CNRI Python Open Source GPL Compatible License " "Agreement",
    },
    "COIL-1.0": {
        "name": "COIL-1.0",
        "path": "https://coil.apotheon.org/plaintext/01.0.txt",
        "title": "Copyfree Open Innovation License",
    },
    "CPAL-1.0": {
        "name": "CPAL-1.0",
        "path": "https://opensource.org/licenses/CPAL-1.0",
        "title": "Common Public Attribution License 1.0",
    },
    "CPL-1.0": {
        "name": "CPL-1.0",
        "path": "https://opensource.org/licenses/CPL-1.0",
        "title": "Common Public License 1.0",
    },
    "CPOL-1.02": {
        "name": "CPOL-1.02",
        "path": "http://www.codeproject.com/info/cpol10.aspx",
        "title": "Code Project Open License 1.02",
    },
    "CUA-OPL-1.0": {
        "name": "CUA-OPL-1.0",
        "path": "https://opensource.org/licenses/CUA-OPL-1.0",
        "title": "CUA Office Public License v1.0",
    },
    "Caldera": {
        "name": "Caldera",
        "path": "http://www.lemis.com/grog/UNIX/ancient-source-all.pdf",
        "title": "Caldera License",
    },
    "Caldera-no-preamble": {
        "name": "Caldera-no-preamble",
        "path": "https://github.com/apache/apr/blob/trunk/LICENSE#L298C6-L298C29",
        "title": "Caldera License (without preamble)",
    },
    "Catharon": {
        "name": "Catharon",
        "path": "https://github.com/scummvm/scummvm/blob/v2.8.0/LICENSES/CatharonLicense.txt",
        "title": "Catharon License",
    },
    "ClArtistic": {
        "name": "ClArtistic",
        "path": "http://gianluca.dellavedova.org/2011/01/03/clarified-artistic-license/",
        "title": "Clarified Artistic License",
    },
    "Clips": {
        "name": "Clips",
        "path": "https://github.com/DrItanium/maya/blob/master/LICENSE.CLIPS",
        "title": "Clips License",
    },
    "Community-Spec-1.0": {
        "name": "Community-Spec-1.0",
        "path": "https://github.com/CommunitySpecification/1.0/blob/master/1._Community_Specification_License-v1.md",
        "title": "Community Specification License 1.0",
    },
    "Condor-1.1": {
        "name": "Condor-1.1",
        "path": "http://research.cs.wisc.edu/condor/license.html#condor",
        "title": "Condor Public License v1.1",
    },
    "Cornell-Lossless-JPEG": {
        "name": "Cornell-Lossless-JPEG",
        "path": "https://android.googlesource.com/platform/external/dng_sdk/+/refs/heads/master/source/dng_lossless_jpeg.cpp#16",
        "title": "Cornell Lossless JPEG License",
    },
    "Cronyx": {
        "name": "Cronyx",
        "path": "https://gitlab.freedesktop.org/xorg/font/alias/-/blob/master/COPYING",
        "title": "Cronyx License",
    },
    "Crossword": {
        "name": "Crossword",
        "path": "https://fedoraproject.org/wiki/Licensing/Crossword",
        "title": "Crossword License",
    },
    "CrystalStacker": {
        "name": "CrystalStacker",
        "path": "https://fedoraproject.org/wiki/Licensing:CrystalStacker?rd=Licensing/CrystalStacker",
        "title": "CrystalStacker License",
    },
    "Cube": {
        "name": "Cube",
        "path": "https://fedoraproject.org/wiki/Licensing/Cube",
        "title": "Cube License",
    },
    "D-FSL-1.0": {
        "name": "D-FSL-1.0",
        "path": "http://www.dipp.nrw.de/d-fsl/lizenzen/",
        "title": "Deutsche Freie Software Lizenz",
    },
    "DEC-3-Clause": {
        "name": "DEC-3-Clause",
        "path": "https://gitlab.freedesktop.org/xorg/xserver/-/blob/master/COPYING?ref_type=heads#L239",
        "title": "DEC 3-Clause License",
    },
    "DL-DE-BY-2.0": {
        "name": "DL-DE-BY-2.0",
        "path": "https://www.govdata.de/dl-de/by-2-0",
        "title": "Data licence Germany – attribution – version 2.0",
    },
    "DL-DE-ZERO-2.0": {
        "name": "DL-DE-ZERO-2.0",
        "path": "https://www.govdata.de/dl-de/zero-2-0",
        "title": "Data licence Germany – zero – version 2.0",
    },
    "DOC": {
        "name": "DOC",
        "path": "http://www.cs.wustl.edu/~schmidt/ACE-copying.html",
        "title": "DOC License",
    },
    "DRL-1.0": {
        "name": "DRL-1.0",
        "path": "https://github.com/Neo23x0/sigma/blob/master/LICENSE.Detection.Rules.md",
        "title": "Detection Rule License 1.0",
    },
    "DRL-1.1": {
        "name": "DRL-1.1",
        "path": "https://github.com/SigmaHQ/Detection-Rule-License/blob/6ec7fbde6101d101b5b5d1fcb8f9b69fbc76c04a/LICENSE.Detection.Rules.md",
        "title": "Detection Rule License 1.1",
    },
    "DSDP": {
        "name": "DSDP",
        "path": "https://fedoraproject.org/wiki/Licensing/DSDP",
        "title": "DSDP License",
    },
    "DocBook-Schema": {
        "name": "DocBook-Schema",
        "path": "https://github.com/docbook/xslt10-stylesheets/blob/efd62655c11cc8773708df7a843613fa1e932bf8/xsl/assembly/schema/docbook51b7.rnc",
        "title": "DocBook Schema License",
    },
    "DocBook-Stylesheet": {
        "name": "DocBook-Stylesheet",
        "path": "http://www.docbook.org/xml/5.0/docbook-5.0.zip",
        "title": "DocBook Stylesheet License",
    },
    "DocBook-XML": {
        "name": "DocBook-XML",
        "path": "https://github.com/docbook/xslt10-stylesheets/blob/efd62655c11cc8773708df7a843613fa1e932bf8/xsl/COPYING#L27",
        "title": "DocBook XML License",
    },
    "Dotseqn": {
        "name": "Dotseqn",
        "path": "https://fedoraproject.org/wiki/Licensing/Dotseqn",
        "title": "Dotseqn License",
    },
    "ECL-1.0": {
        "name": "ECL-1.0",
        "path": "https://opensource.org/licenses/ECL-1.0",
        "title": "Educational Community License v1.0",
    },
    "ECL-2.0": {
        "name": "ECL-2.0",
        "path": "https://opensource.org/licenses/ECL-2.0",
        "title": "Educational Community License v2.0",
    },
    "EFL-1.0": {
        "name": "EFL-1.0",
        "path": "http://www.eiffel-nice.org/license/forum.txt",
        "title": "Eiffel Forum License v1.0",
    },
    "EFL-2.0": {
        "name": "EFL-2.0",
        "path": "http://www.eiffel-nice.org/license/eiffel-forum-license-2.html",
        "title": "Eiffel Forum License v2.0",
    },
    "EPICS": {
        "name": "EPICS",
        "path": "https://epics.anl.gov/license/open.php",
        "title": "EPICS Open License",
    },
    "EPL-1.0": {
        "name": "EPL-1.0",
        "path": "http://www.eclipse.org/legal/epl-v10.html",
        "title": "Eclipse Public License 1.0",
    },
    "EPL-2.0": {
        "name": "EPL-2.0",
        "path": "https://www.eclipse.org/legal/epl-2.0",
        "title": "Eclipse Public License 2.0",
    },
    "EUDatagrid": {
        "name": "EUDatagrid",
        "path": "http://eu-datagrid.web.cern.ch/eu-datagrid/license.html",
        "title": "EU DataGrid Software License",
    },
    "EUPL-1.0": {
        "name": "EUPL-1.0",
        "path": "http://ec.europa.eu/idabc/en/document/7330.html",
        "title": "European Union Public License 1.0",
    },
    "EUPL-1.1": {
        "name": "EUPL-1.1",
        "path": "https://joinup.ec.europa.eu/software/page/eupl/licence-eupl",
        "title": "European Union Public License 1.1",
    },
    "EUPL-1.2": {
        "name": "EUPL-1.2",
        "path": "https://joinup.ec.europa.eu/page/eupl-text-11-12",
        "title": "European Union Public License 1.2",
    },
    "Elastic-2.0": {
        "name": "Elastic-2.0",
        "path": "https://www.elastic.co/licensing/elastic-license",
        "title": "Elastic License 2.0",
    },
    "Entessa": {
        "name": "Entessa",
        "path": "https://opensource.org/licenses/Entessa",
        "title": "Entessa Public License v1.0",
    },
    "ErlPL-1.1": {
        "name": "ErlPL-1.1",
        "path": "http://www.erlang.org/EPLICENSE",
        "title": "Erlang Public License v1.1",
    },
    "Eurosym": {
        "name": "Eurosym",
        "path": "https://fedoraproject.org/wiki/Licensing/Eurosym",
        "title": "Eurosym License",
    },
    "FBM": {
        "name": "FBM",
        "path": "https://github.com/SWI-Prolog/packages-xpce/blob/161a40cd82004f731ba48024f9d30af388a7edf5/src/img/gifwrite.c#L21-L26",
        "title": "Fuzzy Bitmap License",
    },
    "FDK-AAC": {
        "name": "FDK-AAC",
        "path": "https://fedoraproject.org/wiki/Licensing/FDK-AAC",
        "title": "Fraunhofer FDK AAC Codec Library",
    },
    "FSFAP": {
        "name": "FSFAP",
        "path": "https://www.gnu.org/prep/maintain/html_node/License-Notices-for-Other-Files.html",
        "title": "FSF All Permissive License",
    },
    "FSFAP-no-warranty-disclaimer": {
        "name": "FSFAP-no-warranty-disclaimer",
        "path": "https://git.savannah.gnu.org/cgit/wget.git/tree/util/trunc.c?h=v1.21.3&id=40747a11e44ced5a8ac628a41f879ced3e2ebce9#n6",
        "title": "FSF All Permissive License (without Warranty)",
    },
    "FSFUL": {
        "name": "FSFUL",
        "path": "https://fedoraproject.org/wiki/Licensing/FSF_Unlimited_License",
        "title": "FSF Unlimited License",
    },
    "FSFULLR": {
        "name": "FSFULLR",
        "path": "https://fedoraproject.org/wiki/Licensing/FSF_Unlimited_License#License_Retention_Variant",
        "title": "FSF Unlimited License (with License Retention)",
    },
    "FSFULLRWD": {
        "name": "FSFULLRWD",
        "path": "https://lists.gnu.org/archive/html/autoconf/2012-04/msg00061.html",
        "title": "FSF Unlimited License (With License Retention and Warranty Disclaimer)",
    },
    "FTL": {
        "name": "FTL",
        "path": "http://freetype.fis.uniroma2.it/FTL.TXT",
        "title": "Freetype Project License",
    },
    "Fair": {
        "name": "Fair",
        "path": "https://web.archive.org/web/20150926120323/http://fairlicense.org/",
        "title": "Fair License",
    },
    "Ferguson-Twofish": {
        "name": "Ferguson-Twofish",
        "path": "https://github.com/wernerd/ZRTPCPP/blob/6b3cd8e6783642292bad0c21e3e5e5ce45ff3e03/cryptcommon/twofish.c#L113C3-L127",
        "title": "Ferguson Twofish License",
    },
    "Frameworx-1.0": {
        "name": "Frameworx-1.0",
        "path": "https://opensource.org/licenses/Frameworx-1.0",
        "title": "Frameworx Open License 1.0",
    },
    "FreeBSD-DOC": {
        "name": "FreeBSD-DOC",
        "path": "https://www.freebsd.org/copyright/freebsd-doc-license/",
        "title": "FreeBSD Documentation License",
    },
    "FreeImage": {
        "name": "FreeImage",
        "path": "http://freeimage.sourceforge.net/freeimage-license.txt",
        "title": "FreeImage Public License v1.0",
    },
    "Furuseth": {
        "name": "Furuseth",
        "path": "https://git.openldap.org/openldap/openldap/-/blob/master/COPYRIGHT?ref_type=heads#L39-51",
        "title": "Furuseth License",
    },
    "GCR-docs": {
        "name": "GCR-docs",
        "path": "https://github.com/GNOME/gcr/blob/master/docs/COPYING",
        "title": "Gnome GCR Documentation License",
    },
    "GD": {
        "name": "GD",
        "path": "https://libgd.github.io/manuals/2.3.0/files/license-txt.html",
        "title": "GD License",
    },
    "GFDL-1.1-invariants-only": {
        "name": "GFDL-1.1-invariants-only",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.1.txt",
        "title": "GNU Free Documentation License v1.1 only - invariants",
    },
    "GFDL-1.1-invariants-or-later": {
        "name": "GFDL-1.1-invariants-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.1.txt",
        "title": "GNU Free Documentation License v1.1 or later - " "invariants",
    },
    "GFDL-1.1-no-invariants-only": {
        "name": "GFDL-1.1-no-invariants-only",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.1.txt",
        "title": "GNU Free Documentation License v1.1 only - no " "invariants",
    },
    "GFDL-1.1-no-invariants-or-later": {
        "name": "GFDL-1.1-no-invariants-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.1.txt",
        "title": "GNU Free Documentation License v1.1 or later - no " "invariants",
    },
    "GFDL-1.1-only": {
        "name": "GFDL-1.1-only",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.1.txt",
        "title": "GNU Free Documentation License v1.1 only",
    },
    "GFDL-1.1-or-later": {
        "name": "GFDL-1.1-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.1.txt",
        "title": "GNU Free Documentation License v1.1 or later",
    },
    "GFDL-1.2-invariants-only": {
        "name": "GFDL-1.2-invariants-only",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.2.txt",
        "title": "GNU Free Documentation License v1.2 only - invariants",
    },
    "GFDL-1.2-invariants-or-later": {
        "name": "GFDL-1.2-invariants-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.2.txt",
        "title": "GNU Free Documentation License v1.2 or later - " "invariants",
    },
    "GFDL-1.2-no-invariants-only": {
        "name": "GFDL-1.2-no-invariants-only",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.2.txt",
        "title": "GNU Free Documentation License v1.2 only - no " "invariants",
    },
    "GFDL-1.2-no-invariants-or-later": {
        "name": "GFDL-1.2-no-invariants-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.2.txt",
        "title": "GNU Free Documentation License v1.2 or later - no " "invariants",
    },
    "GFDL-1.2-only": {
        "name": "GFDL-1.2-only",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.2.txt",
        "title": "GNU Free Documentation License v1.2 only",
    },
    "GFDL-1.2-or-later": {
        "name": "GFDL-1.2-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/fdl-1.2.txt",
        "title": "GNU Free Documentation License v1.2 or later",
    },
    "GFDL-1.3-invariants-only": {
        "name": "GFDL-1.3-invariants-only",
        "path": "https://www.gnu.org/licenses/fdl-1.3.txt",
        "title": "GNU Free Documentation License v1.3 only - invariants",
    },
    "GFDL-1.3-invariants-or-later": {
        "name": "GFDL-1.3-invariants-or-later",
        "path": "https://www.gnu.org/licenses/fdl-1.3.txt",
        "title": "GNU Free Documentation License v1.3 or later - " "invariants",
    },
    "GFDL-1.3-no-invariants-only": {
        "name": "GFDL-1.3-no-invariants-only",
        "path": "https://www.gnu.org/licenses/fdl-1.3.txt",
        "title": "GNU Free Documentation License v1.3 only - no " "invariants",
    },
    "GFDL-1.3-no-invariants-or-later": {
        "name": "GFDL-1.3-no-invariants-or-later",
        "path": "https://www.gnu.org/licenses/fdl-1.3.txt",
        "title": "GNU Free Documentation License v1.3 or later - no " "invariants",
    },
    "GFDL-1.3-only": {
        "name": "GFDL-1.3-only",
        "path": "https://www.gnu.org/licenses/fdl-1.3.txt",
        "title": "GNU Free Documentation License v1.3 only",
    },
    "GFDL-1.3-or-later": {
        "name": "GFDL-1.3-or-later",
        "path": "https://www.gnu.org/licenses/fdl-1.3.txt",
        "title": "GNU Free Documentation License v1.3 or later",
    },
    "GL2PS": {
        "name": "GL2PS",
        "path": "http://www.geuz.org/gl2ps/COPYING.GL2PS",
        "title": "GL2PS License",
    },
    "GLWTPL": {
        "name": "GLWTPL",
        "path": "https://github.com/me-shaon/GLWTPL/commit/da5f6bc734095efbacb442c0b31e33a65b9d6e85",
        "title": "Good Luck With That Public License",
    },
    "GPL-1.0-only": {
        "name": "GPL-1.0-only",
        "path": "https://www.gnu.org/licenses/old-licenses/gpl-1.0-standalone.html",
        "title": "GNU General Public License v1.0 only",
    },
    "GPL-1.0-or-later": {
        "name": "GPL-1.0-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/gpl-1.0-standalone.html",
        "title": "GNU General Public License v1.0 or later",
    },
    "GPL-2.0-only": {
        "name": "GPL-2.0-only",
        "path": "https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html",
        "title": "GNU General Public License v2.0 only",
    },
    "GPL-2.0-or-later": {
        "name": "GPL-2.0-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html",
        "title": "GNU General Public License v2.0 or later",
    },
    "GPL-3.0-only": {
        "name": "GPL-3.0-only",
        "path": "https://www.gnu.org/licenses/gpl-3.0-standalone.html",
        "title": "GNU General Public License v3.0 only",
    },
    "GPL-3.0-or-later": {
        "name": "GPL-3.0-or-later",
        "path": "https://www.gnu.org/licenses/gpl-3.0-standalone.html",
        "title": "GNU General Public License v3.0 or later",
    },
    "Giftware": {
        "name": "Giftware",
        "path": "http://liballeg.org/license.html#allegro-4-the-giftware-license",
        "title": "Giftware License",
    },
    "Glide": {
        "name": "Glide",
        "path": "http://www.users.on.net/~triforce/glidexp/COPYING.txt",
        "title": "3dfx Glide License",
    },
    "Glulxe": {
        "name": "Glulxe",
        "path": "https://fedoraproject.org/wiki/Licensing/Glulxe",
        "title": "Glulxe License",
    },
    "Graphics-Gems": {
        "name": "Graphics-Gems",
        "path": "https://github.com/erich666/GraphicsGems/blob/master/LICENSE.md",
        "title": "Graphics Gems License",
    },
    "Gutmann": {
        "name": "Gutmann",
        "path": "https://www.cs.auckland.ac.nz/~pgut001/dumpasn1.c",
        "title": "Gutmann License",
    },
    "HIDAPI": {
        "name": "HIDAPI",
        "path": "https://github.com/signal11/hidapi/blob/master/LICENSE-orig.txt",
        "title": "HIDAPI License",
    },
    "HP-1986": {
        "name": "HP-1986",
        "path": "https://sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/machine/hppa/memchr.S;h=1cca3e5e8867aa4bffef1f75a5c1bba25c0c441e;hb=HEAD#l2",
        "title": "Hewlett-Packard 1986 License",
    },
    "HP-1989": {
        "name": "HP-1989",
        "path": "https://github.com/bleargh45/Data-UUID/blob/master/LICENSE",
        "title": "Hewlett-Packard 1989 License",
    },
    "HPND": {
        "name": "HPND",
        "path": "https://opensource.org/licenses/HPND",
        "title": "Historical Permission Notice and Disclaimer",
    },
    "HPND-DEC": {
        "name": "HPND-DEC",
        "path": "https://gitlab.freedesktop.org/xorg/app/xkbcomp/-/blob/master/COPYING?ref_type=heads#L69",
        "title": "Historical Permission Notice and Disclaimer - DEC variant",
    },
    "HPND-Fenneberg-Livingston": {
        "name": "HPND-Fenneberg-Livingston",
        "path": "https://github.com/FreeRADIUS/freeradius-client/blob/master/COPYRIGHT#L32",
        "title": "Historical Permission Notice and Disclaimer - " "Fenneberg-Livingston variant",
    },
    "HPND-INRIA-IMAG": {
        "name": "HPND-INRIA-IMAG",
        "path": "https://github.com/ppp-project/ppp/blob/master/pppd/ipv6cp.c#L75-L83",
        "title": "Historical Permission Notice and Disclaimer    - INRIA-IMAG " "variant",
    },
    "HPND-Intel": {
        "name": "HPND-Intel",
        "path": "https://sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/machine/i960/memcpy.S;hb=HEAD",
        "title": "Historical Permission Notice and Disclaimer - Intel variant",
    },
    "HPND-Kevlin-Henney": {
        "name": "HPND-Kevlin-Henney",
        "path": "https://github.com/mruby/mruby/blob/83d12f8d52522cdb7c8cc46fad34821359f453e6/mrbgems/mruby-dir/src/Win/dirent.c#L127-L140",
        "title": "Historical Permission Notice and Disclaimer - Kevlin Henney " "variant",
    },
    "HPND-MIT-disclaimer": {
        "name": "HPND-MIT-disclaimer",
        "path": "https://metacpan.org/release/NLNETLABS/Net-DNS-SEC-1.22/source/LICENSE",
        "title": "Historical Permission Notice and Disclaimer with MIT " "disclaimer",
    },
    "HPND-Markus-Kuhn": {
        "name": "HPND-Markus-Kuhn",
        "path": "https://www.cl.cam.ac.uk/~mgk25/ucs/wcwidth.c",
        "title": "Historical Permission Notice and Disclaimer - Markus Kuhn variant",
    },
    "HPND-Netrek": {
        "name": "HPND-Netrek",
        "path": "https://spdx.org/licenses/HPND-Netrek.html",
        "title": "Historical Permission Notice and Disclaimer - Netrek variant",
    },
    "HPND-Pbmplus": {
        "name": "HPND-Pbmplus",
        "path": "https://sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/netpbm.c#l8",
        "title": "Historical Permission Notice and Disclaimer - Pbmplus variant",
    },
    "HPND-UC": {
        "name": "HPND-UC",
        "path": "https://core.tcl-lang.org/tk/file?name=compat/unistd.h",
        "title": "Historical Permission Notice and Disclaimer - University of California "
        "variant",
    },
    "HPND-UC-export-US": {
        "name": "HPND-UC-export-US",
        "path": "https://github.com/RTimothyEdwards/magic/blob/master/LICENSE",
        "title": "Historical Permission Notice and Disclaimer - University of "
        "California, US export warning",
    },
    "HPND-doc": {
        "name": "HPND-doc",
        "path": "https://gitlab.freedesktop.org/xorg/lib/libxext/-/blob/master/COPYING?ref_type=heads#L185-197",
        "title": "Historical Permission Notice and Disclaimer - documentation variant",
    },
    "HPND-doc-sell": {
        "name": "HPND-doc-sell",
        "path": "https://gitlab.freedesktop.org/xorg/lib/libxtst/-/blob/master/COPYING?ref_type=heads#L108-117",
        "title": "Historical Permission Notice and Disclaimer - documentation sell " "variant",
    },
    "HPND-export-US": {
        "name": "HPND-export-US",
        "path": "https://www.kermitproject.org/ck90.html#source",
        "title": "HPND with US Government export control warning",
    },
    "HPND-export-US-acknowledgement": {
        "name": "HPND-export-US-acknowledgement",
        "path": "https://github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L831-L852",
        "title": "HPND with US Government export control warning and " "acknowledgment",
    },
    "HPND-export-US-modify": {
        "name": "HPND-export-US-modify",
        "path": "https://github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L1157-L1182",
        "title": "HPND with US Government export control warning and " "modification rqmt",
    },
    "HPND-export2-US": {
        "name": "HPND-export2-US",
        "path": "https://github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L111-L133",
        "title": "HPND with US Government export control and 2 disclaimers",
    },
    "HPND-merchantability-variant": {
        "name": "HPND-merchantability-variant",
        "path": "https://sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/misc/fini.c;hb=HEAD",
        "title": "Historical Permission Notice and Disclaimer - " "merchantability variant",
    },
    "HPND-sell-MIT-disclaimer-xserver": {
        "name": "HPND-sell-MIT-disclaimer-xserver",
        "path": "https://gitlab.freedesktop.org/xorg/xserver/-/blob/master/COPYING?ref_type=heads#L1781",
        "title": "Historical Permission Notice and Disclaimer - sell "
        "xserver variant with MIT disclaimer",
    },
    "HPND-sell-regexpr": {
        "name": "HPND-sell-regexpr",
        "path": "https://gitlab.com/bacula-org/bacula/-/blob/Branch-11.0/bacula/LICENSE-FOSS?ref_type=heads#L245",
        "title": "Historical Permission Notice and Disclaimer - sell regexpr " "variant",
    },
    "HPND-sell-variant": {
        "name": "HPND-sell-variant",
        "path": "https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/tree/net/sunrpc/auth_gss/gss_generic_token.c?h=v4.19",
        "title": "Historical Permission Notice and Disclaimer - sell variant",
    },
    "HPND-sell-variant-MIT-disclaimer": {
        "name": "HPND-sell-variant-MIT-disclaimer",
        "path": "https://github.com/sigmavirus24/x11-ssh-askpass/blob/master/README",
        "title": "HPND sell variant with MIT disclaimer",
    },
    "HPND-sell-variant-MIT-disclaimer-rev": {
        "name": "HPND-sell-variant-MIT-disclaimer-rev",
        "path": "https://github.com/sigmavirus24/x11-ssh-askpass/blob/master/dynlist.c",
        "title": "HPND sell variant with MIT disclaimer - " "reverse",
    },
    "HTMLTIDY": {
        "name": "HTMLTIDY",
        "path": "https://github.com/htacg/tidy-html5/blob/next/README/LICENSE.md",
        "title": "HTML Tidy License",
    },
    "HaskellReport": {
        "name": "HaskellReport",
        "path": "https://fedoraproject.org/wiki/Licensing/Haskell_Language_Report_License",
        "title": "Haskell Language Report License",
    },
    "Hippocratic-2.1": {
        "name": "Hippocratic-2.1",
        "path": "https://firstdonoharm.dev/version/2/1/license.html",
        "title": "Hippocratic License 2.1",
    },
    "IBM-pibs": {
        "name": "IBM-pibs",
        "path": "http://git.denx.de/?p=u-boot.git;a=blob;f=arch/powerpc/cpu/ppc4xx/miiphy.c;h=297155fdafa064b955e53e9832de93bfb0cfb85b;hb=9fab4bf4cc077c21e43941866f3f2c196f28670d",
        "title": "IBM PowerPC Initialization and Boot Software",
    },
    "ICU": {
        "name": "ICU",
        "path": "http://source.icu-project.org/repos/icu/icu/trunk/license.html",
        "title": "ICU License",
    },
    "IEC-Code-Components-EULA": {
        "name": "IEC-Code-Components-EULA",
        "path": "https://www.iec.ch/webstore/custserv/pdf/CC-EULA.pdf",
        "title": "IEC    Code Components End-user licence agreement",
    },
    "IJG": {
        "name": "IJG",
        "path": "http://dev.w3.org/cvsweb/Amaya/libjpeg/Attic/README?rev=1.2",
        "title": "Independent JPEG Group License",
    },
    "IJG-short": {
        "name": "IJG-short",
        "path": "https://sourceforge.net/p/xmedcon/code/ci/master/tree/libs/ljpg/",
        "title": "Independent JPEG Group License - short",
    },
    "IPA": {
        "name": "IPA",
        "path": "https://opensource.org/licenses/IPA",
        "title": "IPA Font License",
    },
    "IPL-1.0": {
        "name": "IPL-1.0",
        "path": "https://opensource.org/licenses/IPL-1.0",
        "title": "IBM Public License v1.0",
    },
    "ISC": {"name": "ISC", "path": "https://www.isc.org/licenses/", "title": "ISC License"},
    "ISC-Veillard": {
        "name": "ISC-Veillard",
        "path": "https://raw.githubusercontent.com/GNOME/libxml2/4c2e7c651f6c2f0d1a74f350cbda95f7df3e7017/hash.c",
        "title": "ISC Veillard variant",
    },
    "ImageMagick": {
        "name": "ImageMagick",
        "path": "http://www.imagemagick.org/script/license.php",
        "title": "ImageMagick License",
    },
    "Imlib2": {
        "name": "Imlib2",
        "path": "http://trac.enlightenment.org/e/browser/trunk/imlib2/COPYING",
        "title": "Imlib2 License",
    },
    "Info-ZIP": {
        "name": "Info-ZIP",
        "path": "http://www.info-zip.org/license.html",
        "title": "Info-ZIP License",
    },
    "Inner-Net-2.0": {
        "name": "Inner-Net-2.0",
        "path": "https://fedoraproject.org/wiki/Licensing/Inner_Net_License",
        "title": "Inner Net License v2.0",
    },
    "Intel": {
        "name": "Intel",
        "path": "https://opensource.org/licenses/Intel",
        "title": "Intel Open Source License",
    },
    "Intel-ACPI": {
        "name": "Intel-ACPI",
        "path": "https://fedoraproject.org/wiki/Licensing/Intel_ACPI_Software_License_Agreement",
        "title": "Intel ACPI Software License Agreement",
    },
    "Interbase-1.0": {
        "name": "Interbase-1.0",
        "path": "https://web.archive.org/web/20060319014854/http://info.borland.com/devsupport/interbase/opensource/IPL.html",
        "title": "Interbase Public License v1.0",
    },
    "JPL-image": {
        "name": "JPL-image",
        "path": "https://www.jpl.nasa.gov/jpl-image-use-policy",
        "title": "JPL Image Use Policy",
    },
    "JPNIC": {
        "name": "JPNIC",
        "path": "https://gitlab.isc.org/isc-projects/bind9/blob/master/COPYRIGHT#L366",
        "title": "Japan Network Information Center License",
    },
    "JSON": {"name": "JSON", "path": "http://www.json.org/license.html", "title": "JSON License"},
    "Jam": {
        "name": "Jam",
        "path": "https://www.boost.org/doc/libs/1_35_0/doc/html/jam.html",
        "title": "Jam License",
    },
    "JasPer-2.0": {
        "name": "JasPer-2.0",
        "path": "http://www.ece.uvic.ca/~mdadams/jasper/LICENSE",
        "title": "JasPer License",
    },
    "Kastrup": {
        "name": "Kastrup",
        "path": "https://ctan.math.utah.edu/ctan/tex-archive/macros/generic/kastrup/binhex.dtx",
        "title": "Kastrup License",
    },
    "Kazlib": {
        "name": "Kazlib",
        "path": "http://git.savannah.gnu.org/cgit/kazlib.git/tree/except.c?id=0062df360c2d17d57f6af19b0e444c51feb99036",
        "title": "Kazlib License",
    },
    "Knuth-CTAN": {
        "name": "Knuth-CTAN",
        "path": "https://ctan.org/license/knuth",
        "title": "Knuth CTAN License",
    },
    "LAL-1.2": {
        "name": "LAL-1.2",
        "path": "http://artlibre.org/licence/lal/licence-art-libre-12/",
        "title": "Licence Art Libre 1.2",
    },
    "LAL-1.3": {
        "name": "LAL-1.3",
        "path": "https://artlibre.org/",
        "title": "Licence Art Libre 1.3",
    },
    "LGPL-2.0-only": {
        "name": "LGPL-2.0-only",
        "path": "https://www.gnu.org/licenses/old-licenses/lgpl-2.0-standalone.html",
        "title": "GNU Library General Public License v2 only",
    },
    "LGPL-2.0-or-later": {
        "name": "LGPL-2.0-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/lgpl-2.0-standalone.html",
        "title": "GNU Library General Public License v2 or later",
    },
    "LGPL-2.1-only": {
        "name": "LGPL-2.1-only",
        "path": "https://www.gnu.org/licenses/old-licenses/lgpl-2.1-standalone.html",
        "title": "GNU Lesser General Public License v2.1 only",
    },
    "LGPL-2.1-or-later": {
        "name": "LGPL-2.1-or-later",
        "path": "https://www.gnu.org/licenses/old-licenses/lgpl-2.1-standalone.html",
        "title": "GNU Lesser General Public License v2.1 or later",
    },
    "LGPL-3.0-only": {
        "name": "LGPL-3.0-only",
        "path": "https://www.gnu.org/licenses/lgpl-3.0-standalone.html",
        "title": "GNU Lesser General Public License v3.0 only",
    },
    "LGPL-3.0-or-later": {
        "name": "LGPL-3.0-or-later",
        "path": "https://www.gnu.org/licenses/lgpl-3.0-standalone.html",
        "title": "GNU Lesser General Public License v3.0 or later",
    },
    "LGPLLR": {
        "name": "LGPLLR",
        "path": "http://www-igm.univ-mlv.fr/~unitex/lgpllr.html",
        "title": "Lesser General Public License For Linguistic Resources",
    },
    "LOOP": {
        "name": "LOOP",
        "path": "https://gitlab.com/embeddable-common-lisp/ecl/-/blob/develop/src/lsp/loop.lsp",
        "title": "Common Lisp LOOP License",
    },
    "LPD-document": {
        "name": "LPD-document",
        "path": "https://github.com/Cyan4973/xxHash/blob/dev/doc/xxhash_spec.md",
        "title": "LPD Documentation License",
    },
    "LPL-1.0": {
        "name": "LPL-1.0",
        "path": "https://opensource.org/licenses/LPL-1.0",
        "title": "Lucent Public License Version 1.0",
    },
    "LPL-1.02": {
        "name": "LPL-1.02",
        "path": "http://plan9.bell-labs.com/plan9/license.html",
        "title": "Lucent Public License v1.02",
    },
    "LPPL-1.0": {
        "name": "LPPL-1.0",
        "path": "http://www.latex-project.org/lppl/lppl-1-0.txt",
        "title": "LaTeX Project Public License v1.0",
    },
    "LPPL-1.1": {
        "name": "LPPL-1.1",
        "path": "http://www.latex-project.org/lppl/lppl-1-1.txt",
        "title": "LaTeX Project Public License v1.1",
    },
    "LPPL-1.2": {
        "name": "LPPL-1.2",
        "path": "http://www.latex-project.org/lppl/lppl-1-2.txt",
        "title": "LaTeX Project Public License v1.2",
    },
    "LPPL-1.3a": {
        "name": "LPPL-1.3a",
        "path": "http://www.latex-project.org/lppl/lppl-1-3a.txt",
        "title": "LaTeX Project Public License v1.3a",
    },
    "LPPL-1.3c": {
        "name": "LPPL-1.3c",
        "path": "http://www.latex-project.org/lppl/lppl-1-3c.txt",
        "title": "LaTeX Project Public License v1.3c",
    },
    "LZMA-SDK-9.11-to-9.20": {
        "name": "LZMA-SDK-9.11-to-9.20",
        "path": "https://www.7-zip.org/sdk.html",
        "title": "LZMA SDK License (versions 9.11 to 9.20)",
    },
    "LZMA-SDK-9.22": {
        "name": "LZMA-SDK-9.22",
        "path": "https://www.7-zip.org/sdk.html",
        "title": "LZMA SDK License (versions 9.22 and beyond)",
    },
    "Latex2e": {
        "name": "Latex2e",
        "path": "https://fedoraproject.org/wiki/Licensing/Latex2e",
        "title": "Latex2e License",
    },
    "Latex2e-translated-notice": {
        "name": "Latex2e-translated-notice",
        "path": "https://git.savannah.gnu.org/cgit/indent.git/tree/doc/indent.texi?id=a74c6b4ee49397cf330b333da1042bffa60ed14f#n74",
        "title": "Latex2e with translated notice permission",
    },
    "Leptonica": {
        "name": "Leptonica",
        "path": "https://fedoraproject.org/wiki/Licensing/Leptonica",
        "title": "Leptonica License",
    },
    "LiLiQ-P-1.1": {
        "name": "LiLiQ-P-1.1",
        "path": "https://forge.gouv.qc.ca/licence/fr/liliq-v1-1/",
        "title": "Licence Libre du Québec – Permissive version 1.1",
    },
    "LiLiQ-R-1.1": {
        "name": "LiLiQ-R-1.1",
        "path": "https://www.forge.gouv.qc.ca/participez/licence-logicielle/licence-libre-du-quebec-liliq-en-francais/licence-libre-du-quebec-reciprocite-liliq-r-v1-1/",
        "title": "Licence Libre du Québec – Réciprocité version 1.1",
    },
    "LiLiQ-Rplus-1.1": {
        "name": "LiLiQ-Rplus-1.1",
        "path": "https://www.forge.gouv.qc.ca/participez/licence-logicielle/licence-libre-du-quebec-liliq-en-francais/licence-libre-du-quebec-reciprocite-forte-liliq-r-v1-1/",
        "title": "Licence Libre du Québec – Réciprocité forte version 1.1",
    },
    "Libpng": {
        "name": "Libpng",
        "path": "http://www.libpng.org/pub/png/src/libpng-LICENSE.txt",
        "title": "libpng License",
    },
    "Linux-OpenIB": {
        "name": "Linux-OpenIB",
        "path": "https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/tree/drivers/infiniband/core/sa.h",
        "title": "Linux Kernel Variant of OpenIB.org license",
    },
    "Linux-man-pages-1-para": {
        "name": "Linux-man-pages-1-para",
        "path": "https://git.kernel.org/pub/scm/docs/man-pages/man-pages.git/tree/man2/getcpu.2#n4",
        "title": "Linux man-pages - 1 paragraph",
    },
    "Linux-man-pages-copyleft": {
        "name": "Linux-man-pages-copyleft",
        "path": "https://www.kernel.org/doc/man-pages/licenses.html",
        "title": "Linux man-pages Copyleft",
    },
    "Linux-man-pages-copyleft-2-para": {
        "name": "Linux-man-pages-copyleft-2-para",
        "path": "https://git.kernel.org/pub/scm/docs/man-pages/man-pages.git/tree/man2/move_pages.2#n5",
        "title": "Linux man-pages Copyleft - 2 paragraphs",
    },
    "Linux-man-pages-copyleft-var": {
        "name": "Linux-man-pages-copyleft-var",
        "path": "https://git.kernel.org/pub/scm/docs/man-pages/man-pages.git/tree/man2/set_mempolicy.2#n5",
        "title": "Linux man-pages Copyleft Variant",
    },
    "Lucida-Bitmap-Fonts": {
        "name": "Lucida-Bitmap-Fonts",
        "path": "https://gitlab.freedesktop.org/xorg/font/bh-100dpi/-/blob/master/COPYING?ref_type=heads",
        "title": "Lucida Bitmap Fonts License",
    },
    "MIT": {"name": "MIT", "path": "https://opensource.org/license/mit/", "title": "MIT License"},
    "MIT-0": {
        "name": "MIT-0",
        "path": "https://github.com/aws/mit-0",
        "title": "MIT No Attribution",
    },
    "MIT-CMU": {
        "name": "MIT-CMU",
        "path": "https://fedoraproject.org/wiki/Licensing:MIT?rd=Licensing/MIT#CMU_Style",
        "title": "CMU License",
    },
    "MIT-Click": {
        "name": "MIT-Click",
        "path": "https://github.com/kohler/t1utils/blob/master/LICENSE",
        "title": "MIT Click License",
    },
    "MIT-Festival": {
        "name": "MIT-Festival",
        "path": "https://github.com/festvox/flite/blob/master/COPYING",
        "title": "MIT Festival Variant",
    },
    "MIT-Khronos-old": {
        "name": "MIT-Khronos-old",
        "path": "https://github.com/KhronosGroup/SPIRV-Cross/blob/main/LICENSES/LicenseRef-KhronosFreeUse.txt",
        "title": "MIT Khronos - old variant",
    },
    "MIT-Modern-Variant": {
        "name": "MIT-Modern-Variant",
        "path": "https://fedoraproject.org/wiki/Licensing:MIT#Modern_Variants",
        "title": "MIT License Modern Variant",
    },
    "MIT-Wu": {
        "name": "MIT-Wu",
        "path": "https://github.com/chromium/octane/blob/master/crypto.js",
        "title": "MIT Tom Wu Variant",
    },
    "MIT-advertising": {
        "name": "MIT-advertising",
        "path": "https://fedoraproject.org/wiki/Licensing/MIT_With_Advertising",
        "title": "Enlightenment License (e16)",
    },
    "MIT-enna": {
        "name": "MIT-enna",
        "path": "https://fedoraproject.org/wiki/Licensing/MIT#enna",
        "title": "enna License",
    },
    "MIT-feh": {
        "name": "MIT-feh",
        "path": "https://fedoraproject.org/wiki/Licensing/MIT#feh",
        "title": "feh License",
    },
    "MIT-open-group": {
        "name": "MIT-open-group",
        "path": "https://gitlab.freedesktop.org/xorg/app/iceauth/-/blob/master/COPYING",
        "title": "MIT Open Group variant",
    },
    "MIT-testregex": {
        "name": "MIT-testregex",
        "path": "https://github.com/dotnet/runtime/blob/55e1ac7c07df62c4108d4acedf78f77574470ce5/src/libraries/System.Text.RegularExpressions/tests/FunctionalTests/AttRegexTests.cs#L12-L28",
        "title": "MIT testregex Variant",
    },
    "MITNFA": {
        "name": "MITNFA",
        "path": "https://fedoraproject.org/wiki/Licensing/MITNFA",
        "title": "MIT +no-false-attribs license",
    },
    "MMIXware": {
        "name": "MMIXware",
        "path": "https://gitlab.lrz.de/mmix/mmixware/-/blob/master/boilerplate.w",
        "title": "MMIXware License",
    },
    "MPEG-SSG": {
        "name": "MPEG-SSG",
        "path": "https://sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/converter/ppm/ppmtompeg/jrevdct.c#l1189",
        "title": "MPEG Software Simulation",
    },
    "MPL-1.0": {
        "name": "MPL-1.0",
        "path": "http://www.mozilla.org/MPL/MPL-1.0.html",
        "title": "Mozilla Public License 1.0",
    },
    "MPL-1.1": {
        "name": "MPL-1.1",
        "path": "http://www.mozilla.org/MPL/MPL-1.1.html",
        "title": "Mozilla Public License 1.1",
    },
    "MPL-2.0": {
        "name": "MPL-2.0",
        "path": "https://www.mozilla.org/MPL/2.0/",
        "title": "Mozilla Public License 2.0",
    },
    "MPL-2.0-no-copyleft-exception": {
        "name": "MPL-2.0-no-copyleft-exception",
        "path": "https://www.mozilla.org/MPL/2.0/",
        "title": "Mozilla Public License 2.0 (no copyleft exception)",
    },
    "MS-LPL": {
        "name": "MS-LPL",
        "path": "https://www.openhub.net/licenses/mslpl",
        "title": "Microsoft Limited Public License",
    },
    "MS-PL": {
        "name": "MS-PL",
        "path": "http://www.microsoft.com/opensource/licenses.mspx",
        "title": "Microsoft Public License",
    },
    "MS-RL": {
        "name": "MS-RL",
        "path": "http://www.microsoft.com/opensource/licenses.mspx",
        "title": "Microsoft Reciprocal License",
    },
    "MTLL": {
        "name": "MTLL",
        "path": "https://fedoraproject.org/wiki/Licensing/Matrix_Template_Library_License",
        "title": "Matrix Template Library License",
    },
    "Mackerras-3-Clause": {
        "name": "Mackerras-3-Clause",
        "path": "https://github.com/ppp-project/ppp/blob/master/pppd/chap_ms.c#L6-L28",
        "title": "Mackerras 3-Clause License",
    },
    "Mackerras-3-Clause-acknowledgment": {
        "name": "Mackerras-3-Clause-acknowledgment",
        "path": "https://github.com/ppp-project/ppp/blob/master/pppd/auth.c#L6-L28",
        "title": "Mackerras 3-Clause - acknowledgment variant",
    },
    "MakeIndex": {
        "name": "MakeIndex",
        "path": "https://fedoraproject.org/wiki/Licensing/MakeIndex",
        "title": "MakeIndex License",
    },
    "Martin-Birgmeier": {
        "name": "Martin-Birgmeier",
        "path": "https://github.com/Perl/perl5/blob/blead/util.c#L6136",
        "title": "Martin Birgmeier License",
    },
    "McPhee-slideshow": {
        "name": "McPhee-slideshow",
        "path": "https://mirror.las.iastate.edu/tex-archive/graphics/metapost/contrib/macros/slideshow/slideshow.mp",
        "title": "McPhee Slideshow License",
    },
    "Minpack": {
        "name": "Minpack",
        "path": "http://www.netlib.org/minpack/disclaimer",
        "title": "Minpack License",
    },
    "MirOS": {
        "name": "MirOS",
        "path": "https://opensource.org/licenses/MirOS",
        "title": "The MirOS Licence",
    },
    "Motosoto": {
        "name": "Motosoto",
        "path": "https://opensource.org/licenses/Motosoto",
        "title": "Motosoto License",
    },
    "MulanPSL-1.0": {
        "name": "MulanPSL-1.0",
        "path": "https://license.coscl.org.cn/MulanPSL/",
        "title": "Mulan Permissive Software License, Version 1",
    },
    "MulanPSL-2.0": {
        "name": "MulanPSL-2.0",
        "path": "https://license.coscl.org.cn/MulanPSL2",
        "title": "Mulan Permissive Software License, Version 2",
    },
    "Multics": {
        "name": "Multics",
        "path": "https://opensource.org/licenses/Multics",
        "title": "Multics License",
    },
    "Mup": {
        "name": "Mup",
        "path": "https://fedoraproject.org/wiki/Licensing/Mup",
        "title": "Mup License",
    },
    "NAIST-2003": {
        "name": "NAIST-2003",
        "path": "https://enterprise.dejacode.com/licenses/public/naist-2003/#license-text",
        "title": "Nara Institute of Science and Technology License (2003)",
    },
    "NASA-1.3": {
        "name": "NASA-1.3",
        "path": "http://ti.arc.nasa.gov/opensource/nosa/",
        "title": "NASA Open Source Agreement 1.3",
    },
    "NBPL-1.0": {
        "name": "NBPL-1.0",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=37b4b3f6cc4bf34e1d3dec61e69914b9819d8894",
        "title": "Net Boolean Public License v1",
    },
    "NCBI-PD": {
        "name": "NCBI-PD",
        "path": "https://github.com/ncbi/sra-tools/blob/e8e5b6af4edc460156ad9ce5902d0779cffbf685/LICENSE",
        "title": "NCBI Public Domain Notice",
    },
    "NCGL-UK-2.0": {
        "name": "NCGL-UK-2.0",
        "path": "http://www.nationalarchives.gov.uk/doc/non-commercial-government-licence/version/2/",
        "title": "Non-Commercial Government Licence",
    },
    "NCL": {
        "name": "NCL",
        "path": "https://gitlab.freedesktop.org/pipewire/pipewire/-/blob/master/src/modules/module-filter-chain/pffft.c?ref_type=heads#L1-52",
        "title": "NCL Source Code License",
    },
    "NCSA": {
        "name": "NCSA",
        "path": "http://otm.illinois.edu/uiuc_openSource",
        "title": "University of Illinois/NCSA Open Source License",
    },
    "NGPL": {
        "name": "NGPL",
        "path": "https://opensource.org/licenses/NGPL",
        "title": "Nethack General Public License",
    },
    "NICTA-1.0": {
        "name": "NICTA-1.0",
        "path": "https://opensource.apple.com/source/mDNSResponder/mDNSResponder-320.10/mDNSPosix/nss_ReadMe.txt",
        "title": "NICTA Public Software License, Version 1.0",
    },
    "NIST-PD": {
        "name": "NIST-PD",
        "path": "https://github.com/tcheneau/simpleRPL/blob/e645e69e38dd4e3ccfeceb2db8cba05b7c2e0cd3/LICENSE.txt",
        "title": "NIST Public Domain Notice",
    },
    "NIST-PD-fallback": {
        "name": "NIST-PD-fallback",
        "path": "https://github.com/usnistgov/jsip/blob/59700e6926cbe96c5cdae897d9a7d2656b42abe3/LICENSE",
        "title": "NIST Public Domain Notice with license fallback",
    },
    "NIST-Software": {
        "name": "NIST-Software",
        "path": "https://github.com/open-quantum-safe/liboqs/blob/40b01fdbb270f8614fde30e65d30e9da18c02393/src/common/rand/rand_nist.c#L1-L15",
        "title": "NIST Software License",
    },
    "NLOD-1.0": {
        "name": "NLOD-1.0",
        "path": "http://data.norge.no/nlod/en/1.0",
        "title": "Norwegian Licence for Open Government Data (NLOD) 1.0",
    },
    "NLOD-2.0": {
        "name": "NLOD-2.0",
        "path": "http://data.norge.no/nlod/en/2.0",
        "title": "Norwegian Licence for Open Government Data (NLOD) 2.0",
    },
    "NLPL": {
        "name": "NLPL",
        "path": "https://fedoraproject.org/wiki/Licensing/NLPL",
        "title": "No Limit Public License",
    },
    "NOSL": {
        "name": "NOSL",
        "path": "http://bits.netizen.com.au/licenses/NOSL/nosl.txt",
        "title": "Netizen Open Source License",
    },
    "NPL-1.0": {
        "name": "NPL-1.0",
        "path": "http://www.mozilla.org/MPL/NPL/1.0/",
        "title": "Netscape Public License v1.0",
    },
    "NPL-1.1": {
        "name": "NPL-1.1",
        "path": "http://www.mozilla.org/MPL/NPL/1.1/",
        "title": "Netscape Public License v1.1",
    },
    "NPOSL-3.0": {
        "name": "NPOSL-3.0",
        "path": "https://opensource.org/licenses/NOSL3.0",
        "title": "Non-Profit Open Software License 3.0",
    },
    "NRL": {
        "name": "NRL",
        "path": "http://web.mit.edu/network/isakmp/nrllicense.html",
        "title": "NRL License",
    },
    "NTP": {"name": "NTP", "path": "https://opensource.org/licenses/NTP", "title": "NTP License"},
    "NTP-0": {
        "name": "NTP-0",
        "path": "https://github.com/tytso/e2fsprogs/blob/master/lib/et/et_name.c",
        "title": "NTP No Attribution",
    },
    "Naumen": {
        "name": "Naumen",
        "path": "https://opensource.org/licenses/Naumen",
        "title": "Naumen Public License",
    },
    "NetCDF": {
        "name": "NetCDF",
        "path": "http://www.unidata.ucar.edu/software/netcdf/copyright.html",
        "title": "NetCDF license",
    },
    "Newsletr": {
        "name": "Newsletr",
        "path": "https://fedoraproject.org/wiki/Licensing/Newsletr",
        "title": "Newsletr License",
    },
    "Nokia": {
        "name": "Nokia",
        "path": "https://opensource.org/licenses/nokia",
        "title": "Nokia Open Source License",
    },
    "Noweb": {
        "name": "Noweb",
        "path": "https://fedoraproject.org/wiki/Licensing/Noweb",
        "title": "Noweb License",
    },
    "O-UDA-1.0": {
        "name": "O-UDA-1.0",
        "path": "https://github.com/microsoft/Open-Use-of-Data-Agreement/blob/v1.0/O-UDA-1.0.md",
        "title": "Open Use of Data Agreement v1.0",
    },
    "OAR": {
        "name": "OAR",
        "path": "https://sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/string/strsignal.c;hb=HEAD#l35",
        "title": "OAR License",
    },
    "OCCT-PL": {
        "name": "OCCT-PL",
        "path": "http://www.opencascade.com/content/occt-public-license",
        "title": "Open CASCADE Technology Public License",
    },
    "OCLC-2.0": {
        "name": "OCLC-2.0",
        "path": "http://www.oclc.org/research/activities/software/license/v2final.htm",
        "title": "OCLC Research Public License 2.0",
    },
    "ODC-By-1.0": {
        "name": "ODC-By-1.0",
        "path": "https://opendatacommons.org/licenses/by/1.0/",
        "title": "Open Data Commons Attribution License v1.0",
    },
    "ODbL-1.0": {
        "name": "ODbL-1.0",
        "path": "http://www.opendatacommons.org/licenses/odbl/1.0/",
        "title": "Open Data Commons Open Database License v1.0",
    },
    "OFFIS": {
        "name": "OFFIS",
        "path": "https://sourceforge.net/p/xmedcon/code/ci/master/tree/libs/dicom/README",
        "title": "OFFIS License",
    },
    "OFL-1.0": {
        "name": "OFL-1.0",
        "path": "http://scripts.sil.org/cms/scripts/page.php?item_id=OFL10_web",
        "title": "SIL Open Font License 1.0",
    },
    "OFL-1.0-RFN": {
        "name": "OFL-1.0-RFN",
        "path": "http://scripts.sil.org/cms/scripts/page.php?item_id=OFL10_web",
        "title": "SIL Open Font License 1.0 with Reserved Font Name",
    },
    "OFL-1.0-no-RFN": {
        "name": "OFL-1.0-no-RFN",
        "path": "http://scripts.sil.org/cms/scripts/page.php?item_id=OFL10_web",
        "title": "SIL Open Font License 1.0 with no Reserved Font Name",
    },
    "OFL-1.1": {
        "name": "OFL-1.1",
        "path": "http://scripts.sil.org/cms/scripts/page.php?item_id=OFL_web",
        "title": "SIL Open Font License 1.1",
    },
    "OFL-1.1-RFN": {
        "name": "OFL-1.1-RFN",
        "path": "http://scripts.sil.org/cms/scripts/page.php?item_id=OFL_web",
        "title": "SIL Open Font License 1.1 with Reserved Font Name",
    },
    "OFL-1.1-no-RFN": {
        "name": "OFL-1.1-no-RFN",
        "path": "http://scripts.sil.org/cms/scripts/page.php?item_id=OFL_web",
        "title": "SIL Open Font License 1.1 with no Reserved Font Name",
    },
    "OGC-1.0": {
        "name": "OGC-1.0",
        "path": "https://www.ogc.org/ogc/software/1.0",
        "title": "OGC Software License, Version 1.0",
    },
    "OGDL-Taiwan-1.0": {
        "name": "OGDL-Taiwan-1.0",
        "path": "https://data.gov.tw/license",
        "title": "Taiwan Open Government Data License, version 1.0",
    },
    "OGL-Canada-2.0": {
        "name": "OGL-Canada-2.0",
        "path": "https://open.canada.ca/en/open-government-licence-canada",
        "title": "Open Government Licence - Canada",
    },
    "OGL-UK-1.0": {
        "name": "OGL-UK-1.0",
        "path": "http://www.nationalarchives.gov.uk/doc/open-government-licence/version/1/",
        "title": "Open Government Licence v1.0",
    },
    "OGL-UK-2.0": {
        "name": "OGL-UK-2.0",
        "path": "http://www.nationalarchives.gov.uk/doc/open-government-licence/version/2/",
        "title": "Open Government Licence v2.0",
    },
    "OGL-UK-3.0": {
        "name": "OGL-UK-3.0",
        "path": "http://www.nationalarchives.gov.uk/doc/open-government-licence/version/3/",
        "title": "Open Government Licence v3.0",
    },
    "OGTSL": {
        "name": "OGTSL",
        "path": "http://www.opengroup.org/testing/downloads/The_Open_Group_TSL.txt",
        "title": "Open Group Test Suite License",
    },
    "OLDAP-1.1": {
        "name": "OLDAP-1.1",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=806557a5ad59804ef3a44d5abfbe91d706b0791f",
        "title": "Open LDAP Public License v1.1",
    },
    "OLDAP-1.2": {
        "name": "OLDAP-1.2",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=42b0383c50c299977b5893ee695cf4e486fb0dc7",
        "title": "Open LDAP Public License v1.2",
    },
    "OLDAP-1.3": {
        "name": "OLDAP-1.3",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=e5f8117f0ce088d0bd7a8e18ddf37eaa40eb09b1",
        "title": "Open LDAP Public License v1.3",
    },
    "OLDAP-1.4": {
        "name": "OLDAP-1.4",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=c9f95c2f3f2ffb5e0ae55fe7388af75547660941",
        "title": "Open LDAP Public License v1.4",
    },
    "OLDAP-2.0": {
        "name": "OLDAP-2.0",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=cbf50f4e1185a21abd4c0a54d3f4341fe28f36ea",
        "title": "Open LDAP Public License v2.0 (or possibly 2.0A and 2.0B)",
    },
    "OLDAP-2.0.1": {
        "name": "OLDAP-2.0.1",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=b6d68acd14e51ca3aab4428bf26522aa74873f0e",
        "title": "Open LDAP Public License v2.0.1",
    },
    "OLDAP-2.1": {
        "name": "OLDAP-2.1",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=b0d176738e96a0d3b9f85cb51e140a86f21be715",
        "title": "Open LDAP Public License v2.1",
    },
    "OLDAP-2.2": {
        "name": "OLDAP-2.2",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=470b0c18ec67621c85881b2733057fecf4a1acc3",
        "title": "Open LDAP Public License v2.2",
    },
    "OLDAP-2.2.1": {
        "name": "OLDAP-2.2.1",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=4bc786f34b50aa301be6f5600f58a980070f481e",
        "title": "Open LDAP Public License v2.2.1",
    },
    "OLDAP-2.2.2": {
        "name": "OLDAP-2.2.2",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=df2cc1e21eb7c160695f5b7cffd6296c151ba188",
        "title": "Open LDAP Public License 2.2.2",
    },
    "OLDAP-2.3": {
        "name": "OLDAP-2.3",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=d32cf54a32d581ab475d23c810b0a7fbaf8d63c3",
        "title": "Open LDAP Public License v2.3",
    },
    "OLDAP-2.4": {
        "name": "OLDAP-2.4",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=cd1284c4a91a8a380d904eee68d1583f989ed386",
        "title": "Open LDAP Public License v2.4",
    },
    "OLDAP-2.5": {
        "name": "OLDAP-2.5",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=6852b9d90022e8593c98205413380536b1b5a7cf",
        "title": "Open LDAP Public License v2.5",
    },
    "OLDAP-2.6": {
        "name": "OLDAP-2.6",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=1cae062821881f41b73012ba816434897abf4205",
        "title": "Open LDAP Public License v2.6",
    },
    "OLDAP-2.7": {
        "name": "OLDAP-2.7",
        "path": "http://www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=47c2415c1df81556eeb39be6cad458ef87c534a2",
        "title": "Open LDAP Public License v2.7",
    },
    "OLDAP-2.8": {
        "name": "OLDAP-2.8",
        "path": "http://www.openldap.org/software/release/license.html",
        "title": "Open LDAP Public License v2.8",
    },
    "OLFL-1.3": {
        "name": "OLFL-1.3",
        "path": "https://openlogisticsfoundation.org/licenses/",
        "title": "Open Logistics Foundation License Version 1.3",
    },
    "OML": {
        "name": "OML",
        "path": "https://fedoraproject.org/wiki/Licensing/Open_Market_License",
        "title": "Open Market License",
    },
    "OPL-1.0": {
        "name": "OPL-1.0",
        "path": "http://old.koalateam.com/jackaroo/OPL_1_0.TXT",
        "title": "Open Public License v1.0",
    },
    "OPL-UK-3.0": {
        "name": "OPL-UK-3.0",
        "path": "https://www.parliament.uk/site-information/copyright-parliament/open-parliament-licence/",
        "title": "United    Kingdom Open Parliament Licence v3.0",
    },
    "OPUBL-1.0": {
        "name": "OPUBL-1.0",
        "path": "http://opencontent.org/openpub/",
        "title": "Open Publication License v1.0",
    },
    "OSET-PL-2.1": {
        "name": "OSET-PL-2.1",
        "path": "http://www.osetfoundation.org/public-license",
        "title": "OSET Public License version 2.1",
    },
    "OSL-1.0": {
        "name": "OSL-1.0",
        "path": "https://opensource.org/licenses/OSL-1.0",
        "title": "Open Software License 1.0",
    },
    "OSL-1.1": {
        "name": "OSL-1.1",
        "path": "https://fedoraproject.org/wiki/Licensing/OSL1.1",
        "title": "Open Software License 1.1",
    },
    "OSL-2.0": {
        "name": "OSL-2.0",
        "path": "http://web.archive.org/web/20041020171434/http://www.rosenlaw.com/osl2.0.html",
        "title": "Open Software License 2.0",
    },
    "OSL-2.1": {
        "name": "OSL-2.1",
        "path": "http://web.archive.org/web/20050212003940/http://www.rosenlaw.com/osl21.htm",
        "title": "Open Software License 2.1",
    },
    "OSL-3.0": {
        "name": "OSL-3.0",
        "path": "https://web.archive.org/web/20120101081418/http://rosenlaw.com:80/OSL3.0.htm",
        "title": "Open Software License 3.0",
    },
    "OpenPBS-2.3": {
        "name": "OpenPBS-2.3",
        "path": "https://github.com/adaptivecomputing/torque/blob/master/PBS_License.txt",
        "title": "OpenPBS v2.3 Software License",
    },
    "OpenSSL": {
        "name": "OpenSSL",
        "path": "http://www.openssl.org/source/license.html",
        "title": "OpenSSL License",
    },
    "OpenSSL-standalone": {
        "name": "OpenSSL-standalone",
        "path": "https://library.netapp.com/ecm/ecm_download_file/ECMP1196395",
        "title": "OpenSSL License - standalone",
    },
    "OpenVision": {
        "name": "OpenVision",
        "path": "https://github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L66-L98",
        "title": "OpenVision License",
    },
    "PADL": {
        "name": "PADL",
        "path": "https://git.openldap.org/openldap/openldap/-/blob/master/libraries/libldap/os-local.c?ref_type=heads#L19-23",
        "title": "PADL License",
    },
    "PDDL-1.0": {
        "name": "PDDL-1.0",
        "path": "http://opendatacommons.org/licenses/pddl/1.0/",
        "title": "Open Data Commons Public Domain Dedication & License 1.0",
    },
    "PHP-3.0": {
        "name": "PHP-3.0",
        "path": "http://www.php.net/license/3_0.txt",
        "title": "PHP License v3.0",
    },
    "PHP-3.01": {
        "name": "PHP-3.01",
        "path": "http://www.php.net/license/3_01.txt",
        "title": "PHP License v3.01",
    },
    "PPL": {
        "name": "PPL",
        "path": "https://wiki.p2pfoundation.net/Peer_Production_License",
        "title": "Peer Production License",
    },
    "PROPRIETARY": {
        "name": "PROPRIETARY",
        "path": "https://example.com",
        "title": "Proprietary data not for use outside originating institution",
    },
    "PSF-2.0": {
        "name": "PSF-2.0",
        "path": "https://opensource.org/licenses/Python-2.0",
        "title": "Python Software Foundation License 2.0",
    },
    "Parity-6.0.0": {
        "name": "Parity-6.0.0",
        "path": "https://paritylicense.com/versions/6.0.0.html",
        "title": "The Parity Public License 6.0.0",
    },
    "Parity-7.0.0": {
        "name": "Parity-7.0.0",
        "path": "https://paritylicense.com/versions/7.0.0.html",
        "title": "The Parity Public License 7.0.0",
    },
    "Pixar": {
        "name": "Pixar",
        "path": "https://github.com/PixarAnimationStudios/OpenSubdiv/raw/v3_5_0/LICENSE.txt",
        "title": "Pixar License",
    },
    "Plexus": {
        "name": "Plexus",
        "path": "https://fedoraproject.org/wiki/Licensing/Plexus_Classworlds_License",
        "title": "Plexus Classworlds License",
    },
    "PolyForm-Noncommercial-1.0.0": {
        "name": "PolyForm-Noncommercial-1.0.0",
        "path": "https://polyformproject.org/licenses/noncommercial/1.0.0",
        "title": "PolyForm Noncommercial License 1.0.0",
    },
    "PolyForm-Small-Business-1.0.0": {
        "name": "PolyForm-Small-Business-1.0.0",
        "path": "https://polyformproject.org/licenses/small-business/1.0.0",
        "title": "PolyForm Small Business License 1.0.0",
    },
    "PostgreSQL": {
        "name": "PostgreSQL",
        "path": "http://www.postgresql.org/about/licence",
        "title": "PostgreSQL License",
    },
    "Python-2.0": {
        "name": "Python-2.0",
        "path": "https://opensource.org/licenses/Python-2.0",
        "title": "Python License 2.0",
    },
    "Python-2.0.1": {
        "name": "Python-2.0.1",
        "path": "https://www.python.org/download/releases/2.0.1/license/",
        "title": "Python License 2.0.1",
    },
    "QPL-1.0": {
        "name": "QPL-1.0",
        "path": "http://doc.qt.nokia.com/3.3/license.html",
        "title": "Q Public License 1.0",
    },
    "QPL-1.0-INRIA-2004": {
        "name": "QPL-1.0-INRIA-2004",
        "path": "https://github.com/maranget/hevea/blob/master/LICENSE",
        "title": "Q Public License 1.0 - INRIA 2004 variant",
    },
    "Qhull": {
        "name": "Qhull",
        "path": "https://fedoraproject.org/wiki/Licensing/Qhull",
        "title": "Qhull License",
    },
    "RHeCos-1.1": {
        "name": "RHeCos-1.1",
        "path": "http://ecos.sourceware.org/old-license.html",
        "title": "Red Hat eCos Public License v1.1",
    },
    "RPL-1.1": {
        "name": "RPL-1.1",
        "path": "https://opensource.org/licenses/RPL-1.1",
        "title": "Reciprocal Public License 1.1",
    },
    "RPL-1.5": {
        "name": "RPL-1.5",
        "path": "https://opensource.org/licenses/RPL-1.5",
        "title": "Reciprocal Public License 1.5",
    },
    "RPSL-1.0": {
        "name": "RPSL-1.0",
        "path": "https://helixcommunity.org/content/rpsl",
        "title": "RealNetworks Public Source License v1.0",
    },
    "RSA-MD": {
        "name": "RSA-MD",
        "path": "http://www.faqs.org/rfcs/rfc1321.html",
        "title": "RSA Message-Digest License",
    },
    "RSCPL": {
        "name": "RSCPL",
        "path": "http://wayback.archive.org/web/20060715140826/http://www.risource.org/RPL/RPL-1.0A.shtml",
        "title": "Ricoh Source Code Public License",
    },
    "Rdisc": {
        "name": "Rdisc",
        "path": "https://fedoraproject.org/wiki/Licensing/Rdisc_License",
        "title": "Rdisc License",
    },
    "Ruby": {
        "name": "Ruby",
        "path": "https://www.ruby-lang.org/en/about/license.txt",
        "title": "Ruby License",
    },
    "Ruby-pty": {
        "name": "Ruby-pty",
        "path": "https://github.com/ruby/ruby/blob/9f6deaa6888a423720b4b127b5314f0ad26cc2e6/ext/pty/pty.c#L775-L786",
        "title": "Ruby pty extension license",
    },
    "SAX-PD": {
        "name": "SAX-PD",
        "path": "http://www.saxproject.org/copying.html",
        "title": "Sax Public Domain Notice",
    },
    "SAX-PD-2.0": {
        "name": "SAX-PD-2.0",
        "path": "http://www.saxproject.org/copying.html",
        "title": "Sax Public Domain Notice 2.0",
    },
    "SCEA": {
        "name": "SCEA",
        "path": "http://research.scea.com/scea_shared_source_license.html",
        "title": "SCEA Shared Source License",
    },
    "SGI-B-1.0": {
        "name": "SGI-B-1.0",
        "path": "http://oss.sgi.com/projects/FreeB/SGIFreeSWLicB.1.0.html",
        "title": "SGI Free Software License B v1.0",
    },
    "SGI-B-1.1": {
        "name": "SGI-B-1.1",
        "path": "http://oss.sgi.com/projects/FreeB/",
        "title": "SGI Free Software License B v1.1",
    },
    "SGI-B-2.0": {
        "name": "SGI-B-2.0",
        "path": "http://oss.sgi.com/projects/FreeB/SGIFreeSWLicB.2.0.pdf",
        "title": "SGI Free Software License B v2.0",
    },
    "SGI-OpenGL": {
        "name": "SGI-OpenGL",
        "path": "https://gitlab.freedesktop.org/mesa/glw/-/blob/master/README?ref_type=heads",
        "title": "SGI OpenGL License",
    },
    "SGP4": {
        "name": "SGP4",
        "path": "https://celestrak.org/publications/AIAA/2006-6753/faq.php",
        "title": "SGP4 Permission Notice",
    },
    "SHL-0.5": {
        "name": "SHL-0.5",
        "path": "https://solderpad.org/licenses/SHL-0.5/",
        "title": "Solderpad Hardware License v0.5",
    },
    "SHL-0.51": {
        "name": "SHL-0.51",
        "path": "https://solderpad.org/licenses/SHL-0.51/",
        "title": "Solderpad Hardware License, Version 0.51",
    },
    "SISSL": {
        "name": "SISSL",
        "path": "http://www.openoffice.org/licenses/sissl_license.html",
        "title": "Sun Industry Standards Source License v1.1",
    },
    "SISSL-1.2": {
        "name": "SISSL-1.2",
        "path": "http://gridscheduler.sourceforge.net/Gridengine_SISSL_license.html",
        "title": "Sun Industry Standards Source License v1.2",
    },
    "SL": {
        "name": "SL",
        "path": "https://github.com/mtoyoda/sl/blob/master/LICENSE",
        "title": "SL License",
    },
    "SMLNJ": {
        "name": "SMLNJ",
        "path": "https://www.smlnj.org/license.html",
        "title": "Standard ML of New Jersey License",
    },
    "SMPPL": {
        "name": "SMPPL",
        "path": "https://github.com/dcblake/SMP/blob/master/Documentation/License.txt",
        "title": "Secure Messaging Protocol Public License",
    },
    "SNIA": {
        "name": "SNIA",
        "path": "https://fedoraproject.org/wiki/Licensing/SNIA_Public_License",
        "title": "SNIA Public License 1.1",
    },
    "SPL-1.0": {
        "name": "SPL-1.0",
        "path": "https://opensource.org/licenses/SPL-1.0",
        "title": "Sun Public License v1.0",
    },
    "SSH-OpenSSH": {
        "name": "SSH-OpenSSH",
        "path": "https://github.com/openssh/openssh-portable/blob/1b11ea7c58cd5c59838b5fa574cd456d6047b2d4/LICENCE#L10",
        "title": "SSH OpenSSH license",
    },
    "SSH-short": {
        "name": "SSH-short",
        "path": "https://github.com/openssh/openssh-portable/blob/1b11ea7c58cd5c59838b5fa574cd456d6047b2d4/pathnames.h",
        "title": "SSH short notice",
    },
    "SSLeay-standalone": {
        "name": "SSLeay-standalone",
        "path": "https://www.tq-group.com/filedownloads/files/software-license-conditions/OriginalSSLeay/OriginalSSLeay.pdf",
        "title": "SSLeay License - standalone",
    },
    "SSPL-1.0": {
        "name": "SSPL-1.0",
        "path": "https://www.mongodb.com/licensing/server-side-public-license",
        "title": "Server Side Public License, v 1",
    },
    "SWL": {
        "name": "SWL",
        "path": "https://fedoraproject.org/wiki/Licensing/SWL",
        "title": "Scheme Widget Library (SWL) Software License Agreement",
    },
    "Saxpath": {
        "name": "Saxpath",
        "path": "https://fedoraproject.org/wiki/Licensing/Saxpath_License",
        "title": "Saxpath License",
    },
    "SchemeReport": {
        "name": "SchemeReport",
        "path": "https://spdx.org/licenses/SchemeReport.html",
        "title": "Scheme Language Report License",
    },
    "Sendmail": {
        "name": "Sendmail",
        "path": "http://www.sendmail.com/pdfs/open_source/sendmail_license.pdf",
        "title": "Sendmail License",
    },
    "Sendmail-8.23": {
        "name": "Sendmail-8.23",
        "path": "https://www.proofpoint.com/sites/default/files/sendmail-license.pdf",
        "title": "Sendmail License 8.23",
    },
    "SimPL-2.0": {
        "name": "SimPL-2.0",
        "path": "https://opensource.org/licenses/SimPL-2.0",
        "title": "Simple Public License 2.0",
    },
    "Sleepycat": {
        "name": "Sleepycat",
        "path": "https://opensource.org/licenses/Sleepycat",
        "title": "Sleepycat License",
    },
    "Soundex": {
        "name": "Soundex",
        "path": "https://metacpan.org/release/RJBS/Text-Soundex-3.05/source/Soundex.pm#L3-11",
        "title": "Soundex License",
    },
    "Spencer-86": {
        "name": "Spencer-86",
        "path": "https://fedoraproject.org/wiki/Licensing/Henry_Spencer_Reg-Ex_Library_License",
        "title": "Spencer License 86",
    },
    "Spencer-94": {
        "name": "Spencer-94",
        "path": "https://fedoraproject.org/wiki/Licensing/Henry_Spencer_Reg-Ex_Library_License",
        "title": "Spencer License 94",
    },
    "Spencer-99": {
        "name": "Spencer-99",
        "path": "http://www.opensource.apple.com/source/tcl/tcl-5/tcl/generic/regfronts.c",
        "title": "Spencer License 99",
    },
    "SugarCRM-1.1.3": {
        "name": "SugarCRM-1.1.3",
        "path": "http://www.sugarcrm.com/crm/SPL",
        "title": "SugarCRM Public License v1.1.3",
    },
    "Sun-PPP": {
        "name": "Sun-PPP",
        "path": "https://github.com/ppp-project/ppp/blob/master/pppd/eap.c#L7-L16",
        "title": "Sun PPP License",
    },
    "Sun-PPP-2000": {
        "name": "Sun-PPP-2000",
        "path": "https://github.com/ppp-project/ppp/blob/master/modules/ppp_ahdlc.c#L7-L19",
        "title": "Sun PPP License (2000)",
    },
    "SunPro": {
        "name": "SunPro",
        "path": "https://github.com/freebsd/freebsd-src/blob/main/lib/msun/src/e_acosh.c",
        "title": "SunPro License",
    },
    "Symlinks": {
        "name": "Symlinks",
        "path": "https://www.mail-archive.com/debian-bugs-rc@lists.debian.org/msg11494.html",
        "title": "Symlinks License",
    },
    "TAPR-OHL-1.0": {
        "name": "TAPR-OHL-1.0",
        "path": "https://www.tapr.org/OHL",
        "title": "TAPR Open Hardware License v1.0",
    },
    "TCL": {
        "name": "TCL",
        "path": "http://www.tcl.tk/software/tcltk/license.html",
        "title": "TCL/TK License",
    },
    "TCP-wrappers": {
        "name": "TCP-wrappers",
        "path": "http://rc.quest.com/topics/openssh/license.php#tcpwrappers",
        "title": "TCP Wrappers License",
    },
    "TGPPL-1.0": {
        "name": "TGPPL-1.0",
        "path": "https://fedoraproject.org/wiki/Licensing/TGPPL",
        "title": "Transitive Grace Period Public Licence 1.0",
    },
    "TMate": {
        "name": "TMate",
        "path": "http://svnkit.com/license.html",
        "title": "TMate Open Source License",
    },
    "TORQUE-1.1": {
        "name": "TORQUE-1.1",
        "path": "https://fedoraproject.org/wiki/Licensing/TORQUEv1.1",
        "title": "TORQUE v2.5+ Software License v1.1",
    },
    "TOSL": {
        "name": "TOSL",
        "path": "https://fedoraproject.org/wiki/Licensing/TOSL",
        "title": "Trusster Open Source License",
    },
    "TPDL": {
        "name": "TPDL",
        "path": "https://metacpan.org/pod/Time::ParseDate#LICENSE",
        "title": "Time::ParseDate License",
    },
    "TPL-1.0": {
        "name": "TPL-1.0",
        "path": "https://fedoraproject.org/wiki/Licensing:ThorPublicLicense",
        "title": "THOR Public License 1.0",
    },
    "TTWL": {
        "name": "TTWL",
        "path": "https://fedoraproject.org/wiki/Licensing/TTWL",
        "title": "Text-Tabs+Wrap License",
    },
    "TTYP0": {
        "name": "TTYP0",
        "path": "https://people.mpi-inf.mpg.de/~uwe/misc/uw-ttyp0/",
        "title": "TTYP0 License",
    },
    "TU-Berlin-1.0": {
        "name": "TU-Berlin-1.0",
        "path": "https://github.com/swh/ladspa/blob/7bf6f3799fdba70fda297c2d8fd9f526803d9680/gsm/COPYRIGHT",
        "title": "Technische Universitaet Berlin License 1.0",
    },
    "TU-Berlin-2.0": {
        "name": "TU-Berlin-2.0",
        "path": "https://github.com/CorsixTH/deps/blob/fd339a9f526d1d9c9f01ccf39e438a015da50035/licences/libgsm.txt",
        "title": "Technische Universitaet Berlin License 2.0",
    },
    "TermReadKey": {
        "name": "TermReadKey",
        "path": "https://github.com/jonathanstowe/TermReadKey/blob/master/README#L9-L10",
        "title": "TermReadKey License",
    },
    "TrustedQSL": {
        "name": "TrustedQSL",
        "path": "https://sourceforge.net/p/trustedqsl/tqsl/ci/master/tree/LICENSE.txt",
        "title": "TrustedQSL License",
    },
    "UCAR": {
        "name": "UCAR",
        "path": "https://github.com/Unidata/UDUNITS-2/blob/master/COPYRIGHT",
        "title": "UCAR License",
    },
    "UCL-1.0": {
        "name": "UCL-1.0",
        "path": "https://opensource.org/licenses/UCL-1.0",
        "title": "Upstream Compatibility License v1.0",
    },
    "UMich-Merit": {
        "name": "UMich-Merit",
        "path": "https://github.com/radcli/radcli/blob/master/COPYRIGHT#L64",
        "title": "Michigan/Merit Networks License",
    },
    "UPL-1.0": {
        "name": "UPL-1.0",
        "path": "https://opensource.org/licenses/UPL",
        "title": "Universal Permissive License v1.0",
    },
    "URT-RLE": {
        "name": "URT-RLE",
        "path": "https://sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/converter/other/pnmtorle.c",
        "title": "Utah Raster Toolkit Run Length Encoded License",
    },
    "Ubuntu-font-1.0": {
        "name": "Ubuntu-font-1.0",
        "path": "https://ubuntu.com/legal/font-licence",
        "title": "Ubuntu Font Licence v1.0",
    },
    "Unicode-3.0": {
        "name": "Unicode-3.0",
        "path": "https://www.unicode.org/license.txt",
        "title": "Unicode License v3",
    },
    "Unicode-DFS-2015": {
        "name": "Unicode-DFS-2015",
        "path": "https://web.archive.org/web/20151224134844/http://unicode.org/copyright.html",
        "title": "Unicode License Agreement - Data Files and Software (2015)",
    },
    "Unicode-DFS-2016": {
        "name": "Unicode-DFS-2016",
        "path": "https://www.unicode.org/license.txt",
        "title": "Unicode License Agreement - Data Files and Software (2016)",
    },
    "Unicode-TOU": {
        "name": "Unicode-TOU",
        "path": "http://web.archive.org/web/20140704074106/http://www.unicode.org/copyright.html",
        "title": "Unicode Terms of Use",
    },
    "UnixCrypt": {
        "name": "UnixCrypt",
        "path": "https://foss.heptapod.net/python-libs/passlib/-/blob/branch/stable/LICENSE#L70",
        "title": "UnixCrypt License",
    },
    "Unlicense": {"name": "Unlicense", "path": "https://unlicense.org/", "title": "The Unlicense"},
    "VOSTROM": {
        "name": "VOSTROM",
        "path": "https://fedoraproject.org/wiki/Licensing/VOSTROM",
        "title": "VOSTROM Public License for Open Source",
    },
    "VSL-1.0": {
        "name": "VSL-1.0",
        "path": "https://opensource.org/licenses/VSL-1.0",
        "title": "Vovida Software License v1.0",
    },
    "Vim": {
        "name": "Vim",
        "path": "http://vimdoc.sourceforge.net/htmldoc/uganda.html",
        "title": "Vim License",
    },
    "W3C": {
        "name": "W3C",
        "path": "http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231.html",
        "title": "W3C Software Notice and License (2002-12-31)",
    },
    "W3C-19980720": {
        "name": "W3C-19980720",
        "path": "http://www.w3.org/Consortium/Legal/copyright-software-19980720.html",
        "title": "W3C Software Notice and License (1998-07-20)",
    },
    "W3C-20150513": {
        "name": "W3C-20150513",
        "path": "https://www.w3.org/Consortium/Legal/2015/copyright-software-and-document",
        "title": "W3C Software Notice and Document License (2015-05-13)",
    },
    "WTFPL": {
        "name": "WTFPL",
        "path": "http://www.wtfpl.net/about/",
        "title": "Do What The F*ck You Want To Public License",
    },
    "Watcom-1.0": {
        "name": "Watcom-1.0",
        "path": "https://opensource.org/licenses/Watcom-1.0",
        "title": "Sybase Open Watcom Public License 1.0",
    },
    "Widget-Workshop": {
        "name": "Widget-Workshop",
        "path": "https://github.com/novnc/noVNC/blob/master/core/crypto/des.js#L24",
        "title": "Widget Workshop License",
    },
    "Wsuipa": {
        "name": "Wsuipa",
        "path": "https://fedoraproject.org/wiki/Licensing/Wsuipa",
        "title": "Wsuipa License",
    },
    "X11": {
        "name": "X11",
        "path": "http://www.xfree86.org/3.3.6/COPYRIGHT2.html#3",
        "title": "X11 License",
    },
    "X11-distribute-modifications-variant": {
        "name": "X11-distribute-modifications-variant",
        "path": "https://github.com/mirror/ncurses/blob/master/COPYING",
        "title": "X11 License Distribution Modification Variant",
    },
    "X11-swapped": {
        "name": "X11-swapped",
        "path": "https://github.com/fedeinthemix/chez-srfi/blob/master/srfi/LICENSE",
        "title": "X11 swapped final paragraphs",
    },
    "XFree86-1.1": {
        "name": "XFree86-1.1",
        "path": "http://www.xfree86.org/current/LICENSE4.html",
        "title": "XFree86 License 1.1",
    },
    "XSkat": {
        "name": "XSkat",
        "path": "https://fedoraproject.org/wiki/Licensing/XSkat_License",
        "title": "XSkat License",
    },
    "Xdebug-1.03": {
        "name": "Xdebug-1.03",
        "path": "https://github.com/xdebug/xdebug/blob/master/LICENSE",
        "title": "Xdebug License v 1.03",
    },
    "Xerox": {
        "name": "Xerox",
        "path": "https://fedoraproject.org/wiki/Licensing/Xerox",
        "title": "Xerox License",
    },
    "Xfig": {
        "name": "Xfig",
        "path": "https://github.com/Distrotech/transfig/blob/master/transfig/transfig.c",
        "title": "Xfig License",
    },
    "Xnet": {
        "name": "Xnet",
        "path": "https://opensource.org/licenses/Xnet",
        "title": "X.Net License",
    },
    "YPL-1.0": {
        "name": "YPL-1.0",
        "path": "http://www.zimbra.com/license/yahoo_public_license_1.0.html",
        "title": "Yahoo! Public License v1.0",
    },
    "YPL-1.1": {
        "name": "YPL-1.1",
        "path": "http://www.zimbra.com/license/yahoo_public_license_1.1.html",
        "title": "Yahoo! Public License v1.1",
    },
    "ZPL-1.1": {
        "name": "ZPL-1.1",
        "path": "http://old.zope.org/Resources/License/ZPL-1.1",
        "title": "Zope Public License 1.1",
    },
    "ZPL-2.0": {
        "name": "ZPL-2.0",
        "path": "http://old.zope.org/Resources/License/ZPL-2.0",
        "title": "Zope Public License 2.0",
    },
    "ZPL-2.1": {
        "name": "ZPL-2.1",
        "path": "http://old.zope.org/Resources/ZPL/",
        "title": "Zope Public License 2.1",
    },
    "Zed": {
        "name": "Zed",
        "path": "https://fedoraproject.org/wiki/Licensing/Zed",
        "title": "Zed License",
    },
    "Zeeff": {
        "name": "Zeeff",
        "path": "ftp://ftp.tin.org/pub/news/utils/newsx/newsx-1.6.tar.gz",
        "title": "Zeeff License",
    },
    "Zend-2.0": {
        "name": "Zend-2.0",
        "path": "https://web.archive.org/web/20130517195954/http://www.zend.com/license/2_00.txt",
        "title": "Zend License v2.0",
    },
    "Zimbra-1.3": {
        "name": "Zimbra-1.3",
        "path": "http://web.archive.org/web/20100302225219/http://www.zimbra.com/license/zimbra-public-license-1-3.html",
        "title": "Zimbra Public License v1.3",
    },
    "Zimbra-1.4": {
        "name": "Zimbra-1.4",
        "path": "http://www.zimbra.com/legal/zimbra-public-license-1-4",
        "title": "Zimbra Public License v1.4",
    },
    "Zlib": {
        "name": "Zlib",
        "path": "http://www.zlib.net/zlib_license.html",
        "title": "zlib License",
    },
    "any-OSI": {
        "name": "any-OSI",
        "path": "https://metacpan.org/pod/Exporter::Tidy#LICENSE",
        "title": "Any OSI License",
    },
    "bcrypt-Solar-Designer": {
        "name": "bcrypt-Solar-Designer",
        "path": "https://github.com/bcrypt-ruby/bcrypt-ruby/blob/master/ext/mri/crypt_blowfish.c",
        "title": "bcrypt Solar Designer License",
    },
    "blessing": {
        "name": "blessing",
        "path": "https://www.sqlite.org/src/artifact/e33a4df7e32d742a?ln=4-9",
        "title": "SQLite Blessing",
    },
    "bzip2-1.0.6": {
        "name": "bzip2-1.0.6",
        "path": "https://sourceware.org/git/?p=bzip2.git;a=blob;f=LICENSE;hb=bzip2-1.0.6",
        "title": "bzip2 and libbzip2 License v1.0.6",
    },
    "check-cvs": {
        "name": "check-cvs",
        "path": "http://cvs.savannah.gnu.org/viewvc/cvs/ccvs/contrib/check_cvs.in?revision=1.1.4.3&view=markup&pathrev=cvs1-11-23#l2",
        "title": "check-cvs License",
    },
    "checkmk": {
        "name": "checkmk",
        "path": "https://github.com/libcheck/check/blob/master/checkmk/checkmk.in",
        "title": "Checkmk License",
    },
    "copyleft-next-0.3.0": {
        "name": "copyleft-next-0.3.0",
        "path": "https://github.com/copyleft-next/copyleft-next/blob/master/Releases/copyleft-next-0.3.0",
        "title": "copyleft-next 0.3.0",
    },
    "copyleft-next-0.3.1": {
        "name": "copyleft-next-0.3.1",
        "path": "https://github.com/copyleft-next/copyleft-next/blob/master/Releases/copyleft-next-0.3.1",
        "title": "copyleft-next 0.3.1",
    },
    "curl": {
        "name": "curl",
        "path": "https://github.com/bagder/curl/blob/master/COPYING",
        "title": "curl License",
    },
    "cve-tou": {
        "name": "cve-tou",
        "path": "https://www.cve.org/Legal/TermsOfUse",
        "title": "Common Vulnerability Enumeration ToU License",
    },
    "diffmark": {
        "name": "diffmark",
        "path": "https://fedoraproject.org/wiki/Licensing/diffmark",
        "title": "diffmark license",
    },
    "dtoa": {
        "name": "dtoa",
        "path": "https://github.com/SWI-Prolog/swipl-devel/blob/master/src/os/dtoa.c",
        "title": "David M. Gay dtoa License",
    },
    "dvipdfm": {
        "name": "dvipdfm",
        "path": "https://fedoraproject.org/wiki/Licensing/dvipdfm",
        "title": "dvipdfm License",
    },
    "eGenix": {
        "name": "eGenix",
        "path": "http://www.egenix.com/products/eGenix.com-Public-License-1.1.0.pdf",
        "title": "eGenix.com Public License 1.1.0",
    },
    "etalab-2.0": {
        "name": "etalab-2.0",
        "path": "https://github.com/DISIC/politique-de-contribution-open-source/blob/master/LICENSE.pdf",
        "title": "Etalab Open License 2.0",
    },
    "fwlw": {
        "name": "fwlw",
        "path": "https://mirrors.nic.cz/tex-archive/macros/latex/contrib/fwlw/README",
        "title": "fwlw License",
    },
    "gSOAP-1.3b": {
        "name": "gSOAP-1.3b",
        "path": "http://www.cs.fsu.edu/~engelen/license.html",
        "title": "gSOAP Public License v1.3b",
    },
    "gnuplot": {
        "name": "gnuplot",
        "path": "https://fedoraproject.org/wiki/Licensing/Gnuplot",
        "title": "gnuplot License",
    },
    "gtkbook": {
        "name": "gtkbook",
        "path": "https://github.com/slogan621/gtkbook",
        "title": "gtkbook License",
    },
    "hdparm": {
        "name": "hdparm",
        "path": "https://github.com/Distrotech/hdparm/blob/4517550db29a91420fb2b020349523b1b4512df2/LICENSE.TXT",
        "title": "hdparm License",
    },
    "iMatix": {
        "name": "iMatix",
        "path": "http://legacy.imatix.com/html/sfl/sfl4.htm#license",
        "title": "iMatix Standard Function Library Agreement",
    },
    "libpng-2.0": {
        "name": "libpng-2.0",
        "path": "http://www.libpng.org/pub/png/src/libpng-LICENSE.txt",
        "title": "PNG Reference Library version 2",
    },
    "libselinux-1.0": {
        "name": "libselinux-1.0",
        "path": "https://github.com/SELinuxProject/selinux/blob/master/libselinux/LICENSE",
        "title": "libselinux public domain notice",
    },
    "libtiff": {
        "name": "libtiff",
        "path": "https://fedoraproject.org/wiki/Licensing/libtiff",
        "title": "libtiff License",
    },
    "libutil-David-Nugent": {
        "name": "libutil-David-Nugent",
        "path": "http://web.mit.edu/freebsd/head/lib/libutil/login_ok.3",
        "title": "libutil David Nugent License",
    },
    "lsof": {
        "name": "lsof",
        "path": "https://github.com/lsof-org/lsof/blob/master/COPYING",
        "title": "lsof License",
    },
    "magaz": {
        "name": "magaz",
        "path": "https://mirrors.nic.cz/tex-archive/macros/latex/contrib/magaz/magaz.tex",
        "title": "magaz License",
    },
    "mailprio": {
        "name": "mailprio",
        "path": "https://fossies.org/linux/sendmail/contrib/mailprio",
        "title": "mailprio License",
    },
    "metamail": {
        "name": "metamail",
        "path": "https://github.com/Dual-Life/mime-base64/blob/master/Base64.xs#L12",
        "title": "metamail License",
    },
    "mpi-permissive": {
        "name": "mpi-permissive",
        "path": "https://sources.debian.org/src/openmpi/4.1.0-10/ompi/debuggers/msgq_interface.h/?hl=19#L19",
        "title": "mpi Permissive License",
    },
    "mpich2": {
        "name": "mpich2",
        "path": "https://fedoraproject.org/wiki/Licensing/MIT",
        "title": "mpich2 License",
    },
    "mplus": {
        "name": "mplus",
        "path": "https://fedoraproject.org/wiki/Licensing:Mplus?rd=Licensing/mplus",
        "title": "mplus Font License",
    },
    "pkgconf": {
        "name": "pkgconf",
        "path": "https://github.com/pkgconf/pkgconf/blob/master/cli/main.c#L8",
        "title": "pkgconf License",
    },
    "pnmstitch": {
        "name": "pnmstitch",
        "path": "https://sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/editor/pnmstitch.c#l2",
        "title": "pnmstitch License",
    },
    "psfrag": {
        "name": "psfrag",
        "path": "https://fedoraproject.org/wiki/Licensing/psfrag",
        "title": "psfrag License",
    },
    "psutils": {
        "name": "psutils",
        "path": "https://fedoraproject.org/wiki/Licensing/psutils",
        "title": "psutils License",
    },
    "python-ldap": {
        "name": "python-ldap",
        "path": "https://github.com/python-ldap/python-ldap/blob/main/LICENCE",
        "title": "Python ldap License",
    },
    "radvd": {
        "name": "radvd",
        "path": "https://github.com/radvd-project/radvd/blob/master/COPYRIGHT",
        "title": "radvd License",
    },
    "snprintf": {
        "name": "snprintf",
        "path": "https://github.com/openssh/openssh-portable/blob/master/openbsd-compat/bsd-snprintf.c#L2",
        "title": "snprintf License",
    },
    "softSurfer": {
        "name": "softSurfer",
        "path": "https://github.com/mm2/Little-CMS/blob/master/src/cmssm.c#L207",
        "title": "softSurfer License",
    },
    "ssh-keyscan": {
        "name": "ssh-keyscan",
        "path": "https://github.com/openssh/openssh-portable/blob/master/LICENCE#L82",
        "title": "ssh-keyscan License",
    },
    "swrule": {
        "name": "swrule",
        "path": "https://ctan.math.utah.edu/ctan/tex-archive/macros/generic/misc/swrule.sty",
        "title": "swrule License",
    },
    "threeparttable": {
        "name": "threeparttable",
        "path": "https://fedoraproject.org/wiki/Licensing/Threeparttable",
        "title": "threeparttable License",
    },
    "ulem": {
        "name": "ulem",
        "path": "https://mirrors.ctan.org/macros/latex/contrib/ulem/README",
        "title": "ulem License",
    },
    "w3m": {
        "name": "w3m",
        "path": "https://github.com/tats/w3m/blob/master/COPYING",
        "title": "w3m License",
    },
    "xinetd": {
        "name": "xinetd",
        "path": "https://fedoraproject.org/wiki/Licensing/Xinetd_License",
        "title": "xinetd License",
    },
    "xkeyboard-config-Zinoviev": {
        "name": "xkeyboard-config-Zinoviev",
        "path": "https://gitlab.freedesktop.org/xkeyboard-config/xkeyboard-config/-/blob/master/COPYING?ref_type=heads#L178",
        "title": "xkeyboard-config Zinoviev License",
    },
    "xlock": {
        "name": "xlock",
        "path": "https://fossies.org/linux/tiff/contrib/ras/ras2tif.c",
        "title": "xlock License",
    },
    "xpp": {
        "name": "xpp",
        "path": "https://fedoraproject.org/wiki/Licensing/xpp",
        "title": "XPP License",
    },
    "xzoom": {
        "name": "xzoom",
        "path": "https://metadata.ftp-master.debian.org/changelogs//main/x/xzoom/xzoom_0.3-27_copyright",
        "title": "xzoom License",
    },
    "zlib-acknowledgement": {
        "name": "zlib-acknowledgement",
        "path": "https://fedoraproject.org/wiki/Licensing/ZlibWithAcknowledgement",
        "title": "zlib/libpng License with Acknowledgement",
    },
}



from datetime import datetime
from pathlib import Path

import pytest

from randonneur import MappingConstants, read_excel_template
from randonneur.licenses import LICENSES

FIXTURES_DIR = Path(__file__).parent / "fixtures"


@pytest.fixture
def fixture() -> Path:
    return FIXTURES_DIR / "randonneur-matching-template-test-fixture.xlsx"


def test_read_excel_template_default(fixture):
    dp = read_excel_template(fixture)

    expected = [
        {
            "source": {
                "name": r"Electric arc furnace dust {CH}| market for electric arc furnace dust | Cut-off, U",
            },
            "target": {
                "reference product": "electric arc furnace dust",
                "name": "market for electric arc furnace dust",
                "location": "CH",
            },
        },
        {
            "source": {
                "name": r"Electric arc furnace dust {Europe without Switzerland}| market for electric arc furnace dust | Cut-off, U",
            },
            "target": {
                "reference product": "electric arc furnace dust",
                "name": "market for electric arc furnace dust",
                "location": "Europe without Switzerland",
            },
        },
    ]

    assert dp.name == "test_1"
    assert dp.description == "test_description"
    assert dp.contributors == [
        {"title": "Alice", "roles": ["author"], "path": "https://example.com"},
        {"title": "Bob", "roles": ["publisher"], "path": "https://example.com"},
    ]
    assert dp.source_id == "SimaPro-9"
    assert dp.target_id == "ecoinvent-3.10-cutoff"
    assert datetime.fromisoformat(dp.created)
    assert dp.mapping == {
        "source": MappingConstants.SIMAPRO_CSV,
        "target": MappingConstants.ECOSPOLD2,
    }
    assert dp.licenses == [LICENSES["CC-BY-4.0"]]
    assert dp.version == "1"
    assert dp.graph_context == ["edges"]
    assert dp.data["update"] == expected


def test_read_excel_template_custom_name(fixture):
    dp = read_excel_template(fixture, worksheet="Custom-name")
    assert dp.name == "test-custom-name"


def test_read_excel_template_missing_section(fixture):
    with pytest.raises(ValueError) as excinfo:
        read_excel_template(fixture, worksheet="Missing-section")
        assert "Missing required section Metadata" in str(excinfo.value)


def test_read_excel_template_custom_license(fixture):
    with pytest.raises(KeyError) as excinfo:
        read_excel_template(fixture, worksheet="Custom-license")
        assert "Can't find given license short name" in str(excinfo.value)

    read_excel_template(
        fixture,
        worksheet="Custom-license",
        license_mapping={
            "foo": {
                "name": "bar",
                "path": "https://example.com",
                "title": "Foo bar license",
            }
        },
    )


def test_read_excel_template_wrong_metadata(fixture):
    with pytest.raises(KeyError) as excinfo:
        read_excel_template(fixture, worksheet="Wrong-metadata")
        assert "Can't understand metadata field" in str(excinfo.value)


def test_read_excel_template_wrong_contributors(fixture):
    with pytest.raises(KeyError) as excinfo:
        read_excel_template(fixture, worksheet="Wrong-contributors")
        assert "Can't find given contributor field" in str(excinfo.value)


def test_read_excel_template_wrong_column_index(fixture):
    with pytest.raises(ValueError) as excinfo:
        read_excel_template(fixture, worksheet="Column-offset")
        assert "'Source' must be the first column in data headers" in str(excinfo.value)


def test_read_excel_template_missing_data(fixture):
    with pytest.raises(ValueError) as excinfo:
        read_excel_template(fixture, worksheet="Missing-data")
        assert "No data found" in str(excinfo.value)


def test_read_excel_template_column_label_not_in_mapping(fixture):
    with pytest.raises(ValueError) as excinfo:
        read_excel_template(fixture, worksheet="Not-in-mapping")
        assert "Data label location not defined in" in str(excinfo.value)


def test_read_excel_template_data_headers(fixture):
    with pytest.raises(ValueError) as excinfo:
        read_excel_template(fixture, worksheet="Data-headers")
        assert "Can't find 'Target' in data headers" in str(excinfo.value)
